# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebEngineCore, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtWebEngineCore`

import PySide6.QtWebEngineCore
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtNetwork
import PySide6.QtWebChannel

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QWebEngineCertificateError(Shiboken.Object):

    class Type(enum.Enum):

        SslObsoleteVersion        = -218
        CertificateKnownInterceptionBlocked = -217
        CertificateSymantecLegacy = -215
        CertificateTransparencyRequired = -214
        CertificateValidityTooLong = -213
        CertificateNameConstraintViolation = -212
        CertificateWeakKey        = -211
        CertificateNonUniqueName  = -210
        CertificateWeakSignatureAlgorithm = -208
        CertificateInvalid        = -207
        CertificateRevoked        = -206
        CertificateUnableToCheckRevocation = -205
        CertificateNoRevocationMechanism = -204
        CertificateContainsErrors = -203
        CertificateAuthorityInvalid = -202
        CertificateDateInvalid    = -201
        CertificateCommonNameInvalid = -200
        SslPinnedKeyNotInCertificateChain = -150
        Ok                        = 0x0


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineCertificateError, /, *, url: PySide6.QtCore.QUrl | None = ..., type: PySide6.QtWebEngineCore.QWebEngineCertificateError.Type | None = ..., description: str | None = ..., overridable: bool | None = ..., isMainFrame: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, url: PySide6.QtCore.QUrl | None = ..., type: PySide6.QtWebEngineCore.QWebEngineCertificateError.Type | None = ..., description: str | None = ..., overridable: bool | None = ..., isMainFrame: bool | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def acceptCertificate(self, /) -> None: ...
    def certificateChain(self, /) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def defer(self, /) -> None: ...
    def description(self, /) -> str: ...
    def isMainFrame(self, /) -> bool: ...
    def isOverridable(self, /) -> bool: ...
    def rejectCertificate(self, /) -> None: ...
    def type(self, /) -> PySide6.QtWebEngineCore.QWebEngineCertificateError.Type: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineClientCertificateSelection(Shiboken.Object):

    def __init__(self, arg__1: PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def certificates(self, /) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def host(self, /) -> PySide6.QtCore.QUrl: ...
    def select(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice, /) -> None: ...
    def selectNone(self, /) -> None: ...


class QWebEngineClientCertificateStore(Shiboken.Object):
    def add(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice, privateKey: PySide6.QtNetwork.QSslKey | int, /) -> None: ...
    def certificates(self, /) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def clear(self, /) -> None: ...
    def remove(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice, /) -> None: ...


class QWebEngineClientHints(PySide6.QtCore.QObject):
    def arch(self, /) -> str: ...
    def bitness(self, /) -> str: ...
    def formFactors(self, /) -> typing.List[str]: ...
    def fullVersion(self, /) -> str: ...
    def fullVersionList(self, /) -> typing.Dict[str, typing.Any]: ...
    def isAllClientHintsEnabled(self, /) -> bool: ...
    def isMobile(self, /) -> bool: ...
    def isWow64(self, /) -> bool: ...
    def model(self, /) -> str: ...
    def platform(self, /) -> str: ...
    def platformVersion(self, /) -> str: ...
    def resetAll(self, /) -> None: ...
    def setAllClientHintsEnabled(self, enabled: bool, /) -> None: ...
    def setArch(self, arg__1: str, /) -> None: ...
    def setBitness(self, arg__1: str, /) -> None: ...
    def setFormFactors(self, arg__1: collections.abc.Sequence[str], /) -> None: ...
    def setFullVersion(self, arg__1: str, /) -> None: ...
    def setFullVersionList(self, arg__1: typing.Dict[str, typing.Any], /) -> None: ...
    def setIsMobile(self, arg__1: bool, /) -> None: ...
    def setIsWow64(self, arg__1: bool, /) -> None: ...
    def setModel(self, arg__1: str, /) -> None: ...
    def setPlatform(self, arg__1: str, /) -> None: ...
    def setPlatformVersion(self, arg__1: str, /) -> None: ...


class QWebEngineContextMenuRequest(PySide6.QtCore.QObject):

    class EditFlag(enum.Flag):

        CanUndo                   = 0x1
        CanRedo                   = 0x2
        CanCut                    = 0x4
        CanCopy                   = 0x8
        CanPaste                  = 0x10
        CanDelete                 = 0x20
        CanSelectAll              = 0x40
        CanTranslate              = 0x80
        CanEditRichly             = 0x100

    class MediaFlag(enum.Flag):

        MediaInError              = 0x1
        MediaPaused               = 0x2
        MediaMuted                = 0x4
        MediaLoop                 = 0x8
        MediaCanSave              = 0x10
        MediaHasAudio             = 0x20
        MediaCanToggleControls    = 0x40
        MediaControls             = 0x80
        MediaCanPrint             = 0x100
        MediaCanRotate            = 0x200

    class MediaType(enum.Enum):

        MediaTypeNone             = 0x0
        MediaTypeImage            = 0x1
        MediaTypeVideo            = 0x2
        MediaTypeAudio            = 0x3
        MediaTypeCanvas           = 0x4
        MediaTypeFile             = 0x5
        MediaTypePlugin           = 0x6


    def editFlags(self, /) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.EditFlag: ...
    def isAccepted(self, /) -> bool: ...
    def isContentEditable(self, /) -> bool: ...
    def linkText(self, /) -> str: ...
    def linkUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def mediaFlags(self, /) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaFlag: ...
    def mediaType(self, /) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaType: ...
    def mediaUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def misspelledWord(self, /) -> str: ...
    def position(self, /) -> PySide6.QtCore.QPoint: ...
    def selectedText(self, /) -> str: ...
    def setAccepted(self, accepted: bool, /) -> None: ...
    def spellCheckerSuggestions(self, /) -> typing.List[str]: ...


class QWebEngineCookieStore(PySide6.QtCore.QObject):

    cookieAdded              : typing.ClassVar[Signal] = ... # cookieAdded(QNetworkCookie)
    cookieRemoved            : typing.ClassVar[Signal] = ... # cookieRemoved(QNetworkCookie)

    class FilterRequest(Shiboken.Object):

        _reservedFlag             = ...  # type: bool
        _reservedType             = ...  # type: int
        firstPartyUrl             = ...  # type: PySide6.QtCore.QUrl
        origin                    = ...  # type: PySide6.QtCore.QUrl
        thirdParty                = ...  # type: bool

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, FilterRequest: PySide6.QtWebEngineCore.QWebEngineCookieStore.FilterRequest, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


    def deleteAllCookies(self, /) -> None: ...
    def deleteCookie(self, cookie: PySide6.QtNetwork.QNetworkCookie, /, origin: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def deleteSessionCookies(self, /) -> None: ...
    def loadAllCookies(self, /) -> None: ...
    def setCookie(self, cookie: PySide6.QtNetwork.QNetworkCookie, /, origin: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def setCookieFilter(self, filterCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...


class QWebEngineDesktopMediaRequest(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineDesktopMediaRequest, /, *, screensModel: PySide6.QtCore.QAbstractListModel | None = ..., windowsModel: PySide6.QtCore.QAbstractListModel | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, screensModel: PySide6.QtCore.QAbstractListModel | None = ..., windowsModel: PySide6.QtCore.QAbstractListModel | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def cancel(self, /) -> None: ...
    def screensModel(self, /) -> PySide6.QtCore.QAbstractListModel: ...
    def selectScreen(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> None: ...
    def selectWindow(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> None: ...
    def windowsModel(self, /) -> PySide6.QtCore.QAbstractListModel: ...


class QWebEngineDownloadRequest(PySide6.QtCore.QObject):

    downloadDirectoryChanged : typing.ClassVar[Signal] = ... # downloadDirectoryChanged()
    downloadFileNameChanged  : typing.ClassVar[Signal] = ... # downloadFileNameChanged()
    interruptReasonChanged   : typing.ClassVar[Signal] = ... # interruptReasonChanged()
    isFinishedChanged        : typing.ClassVar[Signal] = ... # isFinishedChanged()
    isPausedChanged          : typing.ClassVar[Signal] = ... # isPausedChanged()
    receivedBytesChanged     : typing.ClassVar[Signal] = ... # receivedBytesChanged()
    savePageFormatChanged    : typing.ClassVar[Signal] = ... # savePageFormatChanged()
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QWebEngineDownloadRequest::DownloadState)
    totalBytesChanged        : typing.ClassVar[Signal] = ... # totalBytesChanged()

    class DownloadInterruptReason(enum.Enum):

        NoReason                  = 0x0
        FileFailed                = 0x1
        FileAccessDenied          = 0x2
        FileNoSpace               = 0x3
        FileNameTooLong           = 0x5
        FileTooLarge              = 0x6
        FileVirusInfected         = 0x7
        FileTransientError        = 0xa
        FileBlocked               = 0xb
        FileSecurityCheckFailed   = 0xc
        FileTooShort              = 0xd
        FileHashMismatch          = 0xe
        NetworkFailed             = 0x14
        NetworkTimeout            = 0x15
        NetworkDisconnected       = 0x16
        NetworkServerDown         = 0x17
        NetworkInvalidRequest     = 0x18
        ServerFailed              = 0x1e
        ServerBadContent          = 0x21
        ServerUnauthorized        = 0x22
        ServerCertProblem         = 0x23
        ServerForbidden           = 0x24
        ServerUnreachable         = 0x25
        UserCanceled              = 0x28

    class DownloadState(enum.Enum):

        DownloadRequested         = 0x0
        DownloadInProgress        = 0x1
        DownloadCompleted         = 0x2
        DownloadCancelled         = 0x3
        DownloadInterrupted       = 0x4

    class SavePageFormat(enum.Enum):

        UnknownSaveFormat         = -1
        SingleHtmlSaveFormat      = 0x0
        CompleteHtmlSaveFormat    = 0x1
        MimeHtmlSaveFormat        = 0x2


    def accept(self, /) -> None: ...
    def cancel(self, /) -> None: ...
    def downloadDirectory(self, /) -> str: ...
    def downloadFileName(self, /) -> str: ...
    def id(self, /) -> int: ...
    def interruptReason(self, /) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadInterruptReason: ...
    def interruptReasonString(self, /) -> str: ...
    def isFinished(self, /) -> bool: ...
    def isPaused(self, /) -> bool: ...
    def isSavePageDownload(self, /) -> bool: ...
    def mimeType(self, /) -> str: ...
    def page(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def pause(self, /) -> None: ...
    def receivedBytes(self, /) -> int: ...
    def resume(self, /) -> None: ...
    def savePageFormat(self, /) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat: ...
    def setDownloadDirectory(self, directory: str, /) -> None: ...
    def setDownloadFileName(self, fileName: str, /) -> None: ...
    def setSavePageFormat(self, format: PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat, /) -> None: ...
    def state(self, /) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadState: ...
    def suggestedFileName(self, /) -> str: ...
    def totalBytes(self, /) -> int: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineExtensionInfo(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineExtensionInfo, /, *, name: str | None = ..., id: str | None = ..., description: str | None = ..., path: str | None = ..., error: str | None = ..., actionPopupUrl: PySide6.QtCore.QUrl | None = ..., isEnabled: bool | None = ..., isLoaded: bool | None = ..., isInstalled: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, name: str | None = ..., id: str | None = ..., description: str | None = ..., path: str | None = ..., error: str | None = ..., actionPopupUrl: PySide6.QtCore.QUrl | None = ..., isEnabled: bool | None = ..., isLoaded: bool | None = ..., isInstalled: bool | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def actionPopupUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def description(self, /) -> str: ...
    def error(self, /) -> str: ...
    def id(self, /) -> str: ...
    def isEnabled(self, /) -> bool: ...
    def isInstalled(self, /) -> bool: ...
    def isLoaded(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def path(self, /) -> str: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEngineExtensionInfo, /) -> None: ...


class QWebEngineExtensionManager(PySide6.QtCore.QObject):

    installFinished          : typing.ClassVar[Signal] = ... # installFinished(QWebEngineExtensionInfo)
    loadFinished             : typing.ClassVar[Signal] = ... # loadFinished(QWebEngineExtensionInfo)
    uninstallFinished        : typing.ClassVar[Signal] = ... # uninstallFinished(QWebEngineExtensionInfo)
    unloadFinished           : typing.ClassVar[Signal] = ... # unloadFinished(QWebEngineExtensionInfo)
    def event(self, e: PySide6.QtCore.QEvent, /) -> bool: ...
    def extensions(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineExtensionInfo]: ...
    def installExtension(self, path: str, /) -> None: ...
    def installPath(self, /) -> str: ...
    def loadExtension(self, path: str, /) -> None: ...
    def setExtensionEnabled(self, extension: PySide6.QtWebEngineCore.QWebEngineExtensionInfo, enabled: bool, /) -> None: ...
    def uninstallExtension(self, extension: PySide6.QtWebEngineCore.QWebEngineExtensionInfo, /) -> None: ...
    def unloadExtension(self, extension: PySide6.QtWebEngineCore.QWebEngineExtensionInfo, /) -> None: ...


class QWebEngineFileSystemAccessRequest(Shiboken.Object):

    class AccessFlag(enum.Flag):

        Read                      = 0x1
        Write                     = 0x2

    class HandleType(enum.Enum):

        File                      = 0x0
        Directory                 = 0x1


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest, /, *, origin: PySide6.QtCore.QUrl | None = ..., filePath: PySide6.QtCore.QUrl | None = ..., handleType: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType | None = ..., accessFlags: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, origin: PySide6.QtCore.QUrl | None = ..., filePath: PySide6.QtCore.QUrl | None = ..., handleType: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType | None = ..., accessFlags: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest, /) -> bool: ...
    def accept(self, /) -> None: ...
    def accessFlags(self, /) -> PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag: ...
    def filePath(self, /) -> PySide6.QtCore.QUrl: ...
    def handleType(self, /) -> PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def reject(self, /) -> None: ...


class QWebEngineFindTextResult(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFindTextResult, /, *, numberOfMatches: int | None = ..., activeMatch: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, numberOfMatches: int | None = ..., activeMatch: int | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def activeMatch(self, /) -> int: ...
    def numberOfMatches(self, /) -> int: ...


class QWebEngineFrame(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFrame, /, *, isValid: bool | None = ..., name: str | None = ..., htmlName: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., size: PySide6.QtCore.QSizeF | None = ..., isMainFrame: bool | None = ..., children: collections.abc.Sequence[PySide6.QtWebEngineCore.QWebEngineFrame] | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, isValid: bool | None = ..., name: str | None = ..., htmlName: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., size: PySide6.QtCore.QSizeF | None = ..., isMainFrame: bool | None = ..., children: collections.abc.Sequence[PySide6.QtWebEngineCore.QWebEngineFrame] | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtWebEngineCore.QWebEngineFrame, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtWebEngineCore.QWebEngineFrame, /) -> bool: ...
    def children(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineFrame]: ...
    def htmlName(self, /) -> str: ...
    def isMainFrame(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def name(self, /) -> str: ...
    @typing.overload
    def printToPdf(self, filePath: str, /) -> None: ...
    @typing.overload
    def printToPdf(self, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    @typing.overload
    def runJavaScript(self, scriptSource: str, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    @typing.overload
    def runJavaScript(self, scriptSource: str, worldId: int, /, resultCallback: collections.abc.Callable[..., typing.Any] = ...) -> None: ...
    def size(self, /) -> PySide6.QtCore.QSizeF: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineFullScreenRequest(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFullScreenRequest, /, *, toggleOn: bool | None = ..., origin: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, toggleOn: bool | None = ..., origin: PySide6.QtCore.QUrl | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def accept(self, /) -> None: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def reject(self, /) -> None: ...
    def toggleOn(self, /) -> bool: ...


class QWebEngineGlobalSettings(Shiboken.Object):

    class DnsMode(Shiboken.Object):

        secureMode                = ...  # type: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.SecureDnsMode
        serverTemplates           = ...  # type: typing.List[str]

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, DnsMode: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class SecureDnsMode(enum.Enum):

        SystemOnly                = 0x0
        SecureWithFallback        = 0x1
        SecureOnly                = 0x2


    @staticmethod
    def setDnsMode(dnsMode: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode, /) -> bool: ...


class QWebEngineHistory(PySide6.QtCore.QObject):
    def __lshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def back(self, /) -> None: ...
    def backItem(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def backItems(self, maxItems: int, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def backItemsModel(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...
    def canGoBack(self, /) -> bool: ...
    def canGoForward(self, /) -> bool: ...
    def clear(self, /) -> None: ...
    def count(self, /) -> int: ...
    def currentItem(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def currentItemIndex(self, /) -> int: ...
    def forward(self, /) -> None: ...
    def forwardItem(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def forwardItems(self, maxItems: int, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def forwardItemsModel(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...
    def goToItem(self, item: PySide6.QtWebEngineCore.QWebEngineHistoryItem, /) -> None: ...
    def itemAt(self, i: int, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def items(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def itemsModel(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...


class QWebEngineHistoryItem(Shiboken.Object):

    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineHistoryItem, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def iconUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def isValid(self, /) -> bool: ...
    def lastVisited(self, /) -> PySide6.QtCore.QDateTime: ...
    def originalUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def title(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineHistoryModel(PySide6.QtCore.QAbstractListModel):

    class Roles(enum.Enum):

        UrlRole                   = 0x100
        TitleRole                 = 0x101
        OffsetRole                = 0x102
        IconUrlRole               = 0x103


    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /, role: int = ...) -> typing.Any: ...
    def reset(self, /) -> None: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...


class QWebEngineHttpRequest(Shiboken.Object):

    class Method(enum.Enum):

        Get                       = 0x0
        Post                      = 0x1


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> None: ...
    @typing.overload
    def __init__(self, /, url: PySide6.QtCore.QUrl | str = ..., method: PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method = ...) -> None: ...

    def __eq__(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> bool: ...
    def __ne__(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> bool: ...
    def hasHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> bool: ...
    def header(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtCore.QByteArray: ...
    def headers(self, /) -> typing.List[PySide6.QtCore.QByteArray]: ...
    def method(self, /) -> PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method: ...
    def postData(self, /) -> PySide6.QtCore.QByteArray: ...
    @staticmethod
    def postRequest(url: PySide6.QtCore.QUrl | str, postData: typing.Dict[str, str], /) -> PySide6.QtWebEngineCore.QWebEngineHttpRequest: ...
    def setHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, value: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setMethod(self, method: PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method, /) -> None: ...
    def setPostData(self, postData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> None: ...
    def unsetHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineLoadingInfo(Shiboken.Object):

    class ErrorDomain(enum.Enum):

        NoErrorDomain             = 0x0
        InternalErrorDomain       = 0x1
        ConnectionErrorDomain     = 0x2
        CertificateErrorDomain    = 0x3
        HttpErrorDomain           = 0x4
        FtpErrorDomain            = 0x5
        DnsErrorDomain            = 0x6
        HttpStatusCodeDomain      = 0x7

    class LoadStatus(enum.Enum):

        LoadStartedStatus         = 0x0
        LoadStoppedStatus         = 0x1
        LoadSucceededStatus       = 0x2
        LoadFailedStatus          = 0x3


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineLoadingInfo, /, *, url: PySide6.QtCore.QUrl | None = ..., isErrorPage: bool | None = ..., status: PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus | None = ..., errorString: str | None = ..., errorDomain: PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain | None = ..., errorCode: int | None = ..., responseHeaders: typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray] | None = ..., isDownload: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, url: PySide6.QtCore.QUrl | None = ..., isErrorPage: bool | None = ..., status: PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus | None = ..., errorString: str | None = ..., errorDomain: PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain | None = ..., errorCode: int | None = ..., responseHeaders: typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray] | None = ..., isDownload: bool | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def errorCode(self, /) -> int: ...
    def errorDomain(self, /) -> PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain: ...
    def errorString(self, /) -> str: ...
    def isDownload(self, /) -> bool: ...
    def isErrorPage(self, /) -> bool: ...
    def responseHeaders(self, /) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def status(self, /) -> PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineNavigationRequest(PySide6.QtCore.QObject):

    actionChanged            : typing.ClassVar[Signal] = ... # actionChanged()

    class NavigationRequestAction(enum.Enum):

        AcceptRequest             = 0x0
        IgnoreRequest             = 0xff

    class NavigationType(enum.Enum):

        LinkClickedNavigation     = 0x0
        TypedNavigation           = 0x1
        FormSubmittedNavigation   = 0x2
        BackForwardNavigation     = 0x3
        ReloadNavigation          = 0x4
        OtherNavigation           = 0x5
        RedirectNavigation        = 0x6


    def accept(self, /) -> None: ...
    def hasFormData(self, /) -> bool: ...
    def isMainFrame(self, /) -> bool: ...
    def navigationType(self, /) -> PySide6.QtWebEngineCore.QWebEngineNavigationRequest.NavigationType: ...
    def reject(self, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineNewWindowRequest(PySide6.QtCore.QObject):

    class DestinationType(enum.Enum):

        InNewWindow               = 0x0
        InNewTab                  = 0x1
        InNewDialog               = 0x2
        InNewBackgroundTab        = 0x3


    def destination(self, /) -> PySide6.QtWebEngineCore.QWebEngineNewWindowRequest.DestinationType: ...
    def isUserInitiated(self, /) -> bool: ...
    def openIn(self, arg__1: PySide6.QtWebEngineCore.QWebEnginePage, /) -> None: ...
    def requestedGeometry(self, /) -> PySide6.QtCore.QRect: ...
    def requestedUrl(self, /) -> PySide6.QtCore.QUrl: ...


class QWebEngineNotification(PySide6.QtCore.QObject):

    closed                   : typing.ClassVar[Signal] = ... # closed()
    def click(self, /) -> None: ...
    def close(self, /) -> None: ...
    def direction(self, /) -> PySide6.QtCore.Qt.LayoutDirection: ...
    def icon(self, /) -> PySide6.QtGui.QImage: ...
    def language(self, /) -> str: ...
    def matches(self, other: PySide6.QtWebEngineCore.QWebEngineNotification, /) -> bool: ...
    def message(self, /) -> str: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def show(self, /) -> None: ...
    def tag(self, /) -> str: ...
    def title(self, /) -> str: ...


class QWebEnginePage(PySide6.QtCore.QObject):

    _q_aboutToDelete         : typing.ClassVar[Signal] = ... # _q_aboutToDelete()
    audioMutedChanged        : typing.ClassVar[Signal] = ... # audioMutedChanged(bool)
    authenticationRequired   : typing.ClassVar[Signal] = ... # authenticationRequired(QUrl,QAuthenticator*)
    certificateError         : typing.ClassVar[Signal] = ... # certificateError(QWebEngineCertificateError)
    contentsSizeChanged      : typing.ClassVar[Signal] = ... # contentsSizeChanged(QSizeF)
    desktopMediaRequested    : typing.ClassVar[Signal] = ... # desktopMediaRequested(QWebEngineDesktopMediaRequest)
    featurePermissionRequestCanceled: typing.ClassVar[Signal] = ... # featurePermissionRequestCanceled(QUrl,QWebEnginePage::Feature)
    featurePermissionRequested: typing.ClassVar[Signal] = ... # featurePermissionRequested(QUrl,QWebEnginePage::Feature)
    fileSystemAccessRequested: typing.ClassVar[Signal] = ... # fileSystemAccessRequested(QWebEngineFileSystemAccessRequest)
    findTextFinished         : typing.ClassVar[Signal] = ... # findTextFinished(QWebEngineFindTextResult)
    fullScreenRequested      : typing.ClassVar[Signal] = ... # fullScreenRequested(QWebEngineFullScreenRequest)
    geometryChangeRequested  : typing.ClassVar[Signal] = ... # geometryChangeRequested(QRect)
    iconChanged              : typing.ClassVar[Signal] = ... # iconChanged(QIcon)
    iconUrlChanged           : typing.ClassVar[Signal] = ... # iconUrlChanged(QUrl)
    lifecycleStateChanged    : typing.ClassVar[Signal] = ... # lifecycleStateChanged(LifecycleState)
    linkHovered              : typing.ClassVar[Signal] = ... # linkHovered(QString)
    loadFinished             : typing.ClassVar[Signal] = ... # loadFinished(bool)
    loadProgress             : typing.ClassVar[Signal] = ... # loadProgress(int)
    loadStarted              : typing.ClassVar[Signal] = ... # loadStarted()
    loadingChanged           : typing.ClassVar[Signal] = ... # loadingChanged(QWebEngineLoadingInfo)
    navigationRequested      : typing.ClassVar[Signal] = ... # navigationRequested(QWebEngineNavigationRequest&)
    newWindowRequested       : typing.ClassVar[Signal] = ... # newWindowRequested(QWebEngineNewWindowRequest&)
    pdfPrintingFinished      : typing.ClassVar[Signal] = ... # pdfPrintingFinished(QString,bool)
    permissionRequested      : typing.ClassVar[Signal] = ... # permissionRequested(QWebEnginePermission)
    printRequested           : typing.ClassVar[Signal] = ... # printRequested()
    printRequestedByFrame    : typing.ClassVar[Signal] = ... # printRequestedByFrame(QWebEngineFrame)
    proxyAuthenticationRequired: typing.ClassVar[Signal] = ... # proxyAuthenticationRequired(QUrl,QAuthenticator*,QString)
    quotaRequested           : typing.ClassVar[Signal] = ... # quotaRequested(QWebEngineQuotaRequest)
    recentlyAudibleChanged   : typing.ClassVar[Signal] = ... # recentlyAudibleChanged(bool)
    recommendedStateChanged  : typing.ClassVar[Signal] = ... # recommendedStateChanged(LifecycleState)
    registerProtocolHandlerRequested: typing.ClassVar[Signal] = ... # registerProtocolHandlerRequested(QWebEngineRegisterProtocolHandlerRequest)
    renderProcessPidChanged  : typing.ClassVar[Signal] = ... # renderProcessPidChanged(qlonglong)
    renderProcessTerminated  : typing.ClassVar[Signal] = ... # renderProcessTerminated(RenderProcessTerminationStatus,int)
    scrollPositionChanged    : typing.ClassVar[Signal] = ... # scrollPositionChanged(QPointF)
    selectClientCertificate  : typing.ClassVar[Signal] = ... # selectClientCertificate(QWebEngineClientCertificateSelection)
    selectionChanged         : typing.ClassVar[Signal] = ... # selectionChanged()
    titleChanged             : typing.ClassVar[Signal] = ... # titleChanged(QString)
    urlChanged               : typing.ClassVar[Signal] = ... # urlChanged(QUrl)
    visibleChanged           : typing.ClassVar[Signal] = ... # visibleChanged(bool)
    webAuthUxRequested       : typing.ClassVar[Signal] = ... # webAuthUxRequested(QWebEngineWebAuthUxRequest*)
    windowCloseRequested     : typing.ClassVar[Signal] = ... # windowCloseRequested()
    zoomFactorChanged        : typing.ClassVar[Signal] = ... # zoomFactorChanged(double)

    class Feature(enum.Enum):

        Notifications             = 0x0
        Geolocation               = 0x1
        MediaAudioCapture         = 0x2
        MediaVideoCapture         = 0x3
        MediaAudioVideoCapture    = 0x4
        MouseLock                 = 0x5
        DesktopVideoCapture       = 0x6
        DesktopAudioVideoCapture  = 0x7
        ClipboardReadWrite        = 0x8
        LocalFontsAccess          = 0x9

    class FileSelectionMode(enum.Enum):

        FileSelectOpen            = 0x0
        FileSelectOpenMultiple    = 0x1
        FileSelectUploadFolder    = 0x2
        FileSelectSave            = 0x3

    class FindFlag(enum.Flag):

        FindBackward              = 0x1
        FindCaseSensitively       = 0x2

    class JavaScriptConsoleMessageLevel(enum.Enum):

        InfoMessageLevel          = 0x0
        WarningMessageLevel       = 0x1
        ErrorMessageLevel         = 0x2

    class LifecycleState(enum.Enum):

        Active                    = 0x0
        Frozen                    = 0x1
        Discarded                 = 0x2

    class NavigationType(enum.Enum):

        NavigationTypeLinkClicked = 0x0
        NavigationTypeTyped       = 0x1
        NavigationTypeFormSubmitted = 0x2
        NavigationTypeBackForward = 0x3
        NavigationTypeReload      = 0x4
        NavigationTypeOther       = 0x5
        NavigationTypeRedirect    = 0x6

    class PermissionPolicy(enum.Enum):

        PermissionUnknown         = 0x0
        PermissionGrantedByUser   = 0x1
        PermissionDeniedByUser    = 0x2

    class RenderProcessTerminationStatus(enum.Enum):

        NormalTerminationStatus   = 0x0
        AbnormalTerminationStatus = 0x1
        CrashedTerminationStatus  = 0x2
        KilledTerminationStatus   = 0x3

    class WebAction(enum.Enum):

        NoWebAction               = -1
        Back                      = 0x0
        Forward                   = 0x1
        Stop                      = 0x2
        Reload                    = 0x3
        Cut                       = 0x4
        Copy                      = 0x5
        Paste                     = 0x6
        Undo                      = 0x7
        Redo                      = 0x8
        SelectAll                 = 0x9
        ReloadAndBypassCache      = 0xa
        PasteAndMatchStyle        = 0xb
        OpenLinkInThisWindow      = 0xc
        OpenLinkInNewWindow       = 0xd
        OpenLinkInNewTab          = 0xe
        CopyLinkToClipboard       = 0xf
        DownloadLinkToDisk        = 0x10
        CopyImageToClipboard      = 0x11
        CopyImageUrlToClipboard   = 0x12
        DownloadImageToDisk       = 0x13
        CopyMediaUrlToClipboard   = 0x14
        ToggleMediaControls       = 0x15
        ToggleMediaLoop           = 0x16
        ToggleMediaPlayPause      = 0x17
        ToggleMediaMute           = 0x18
        DownloadMediaToDisk       = 0x19
        InspectElement            = 0x1a
        ExitFullScreen            = 0x1b
        RequestClose              = 0x1c
        Unselect                  = 0x1d
        SavePage                  = 0x1e
        OpenLinkInNewBackgroundTab = 0x1f
        ViewSource                = 0x20
        ToggleBold                = 0x21
        ToggleItalic              = 0x22
        ToggleUnderline           = 0x23
        ToggleStrikethrough       = 0x24
        AlignLeft                 = 0x25
        AlignCenter               = 0x26
        AlignRight                = 0x27
        AlignJustified            = 0x28
        Indent                    = 0x29
        Outdent                   = 0x2a
        InsertOrderedList         = 0x2b
        InsertUnorderedList       = 0x2c
        ChangeTextDirectionLTR    = 0x2d
        ChangeTextDirectionRTL    = 0x2e
        WebActionCount            = 0x2f

    class WebWindowType(enum.Enum):

        WebBrowserWindow          = 0x0
        WebBrowserTab             = 0x1
        WebDialog                 = 0x2
        WebBrowserBackgroundTab   = 0x3


    @typing.overload
    def __init__(self, profile: PySide6.QtWebEngineCore.QWebEngineProfile, /, parent: PySide6.QtCore.QObject | None = ..., *, selectedText: str | None = ..., hasSelection: bool | None = ..., requestedUrl: PySide6.QtCore.QUrl | None = ..., zoomFactor: float | None = ..., title: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., iconUrl: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtGui.QIcon | None = ..., backgroundColor: PySide6.QtGui.QColor | None = ..., contentsSize: PySide6.QtCore.QSizeF | None = ..., scrollPosition: PySide6.QtCore.QPointF | None = ..., audioMuted: bool | None = ..., recentlyAudible: bool | None = ..., visible: bool | None = ..., lifecycleState: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState | None = ..., recommendedState: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState | None = ..., renderProcessPid: int | None = ..., loading: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, selectedText: str | None = ..., hasSelection: bool | None = ..., requestedUrl: PySide6.QtCore.QUrl | None = ..., zoomFactor: float | None = ..., title: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., iconUrl: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtGui.QIcon | None = ..., backgroundColor: PySide6.QtGui.QColor | None = ..., contentsSize: PySide6.QtCore.QSizeF | None = ..., scrollPosition: PySide6.QtCore.QPointF | None = ..., audioMuted: bool | None = ..., recentlyAudible: bool | None = ..., visible: bool | None = ..., lifecycleState: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState | None = ..., recommendedState: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState | None = ..., renderProcessPid: int | None = ..., loading: bool | None = ...) -> None: ...

    def acceptAsNewWindow(self, request: PySide6.QtWebEngineCore.QWebEngineNewWindowRequest, /) -> None: ...
    def acceptNavigationRequest(self, url: PySide6.QtCore.QUrl | str, type: PySide6.QtWebEngineCore.QWebEnginePage.NavigationType, isMainFrame: bool, /) -> bool: ...
    def action(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction, /) -> PySide6.QtGui.QAction: ...
    def backgroundColor(self, /) -> PySide6.QtGui.QColor: ...
    def chooseFiles(self, mode: PySide6.QtWebEngineCore.QWebEnginePage.FileSelectionMode, oldFiles: collections.abc.Sequence[str], acceptedMimeTypes: collections.abc.Sequence[str], /) -> typing.List[str]: ...
    def contentsSize(self, /) -> PySide6.QtCore.QSizeF: ...
    def createWindow(self, type: PySide6.QtWebEngineCore.QWebEnginePage.WebWindowType, /) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def devToolsId(self, /) -> str: ...
    def devToolsPage(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def download(self, url: PySide6.QtCore.QUrl | str, /, filename: str = ...) -> None: ...
    def event(self, arg__1: PySide6.QtCore.QEvent, /) -> bool: ...
    def findFrameByName(self, name: str, /) -> PySide6.QtWebEngineCore.QWebEngineFrame: ...
    @typing.overload
    def findText(self, subString: str, /, options: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag = ...) -> None: ...
    @typing.overload
    def findText(self, subString: str, options: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def hasSelection(self, /) -> bool: ...
    def history(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistory: ...
    def icon(self, /) -> PySide6.QtGui.QIcon: ...
    def iconUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def inspectedPage(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def isAudioMuted(self, /) -> bool: ...
    def isLoading(self, /) -> bool: ...
    def isVisible(self, /) -> bool: ...
    def javaScriptAlert(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str, /) -> None: ...
    def javaScriptConfirm(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str, /) -> bool: ...
    def javaScriptConsoleMessage(self, level: PySide6.QtWebEngineCore.QWebEnginePage.JavaScriptConsoleMessageLevel, message: str, lineNumber: int, sourceID: str, /) -> None: ...
    def javaScriptPrompt(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str, defaultValue: str, /) -> typing.Tuple[bool, str]: ...
    def lifecycleState(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState: ...
    @typing.overload
    def load(self, request: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> None: ...
    @typing.overload
    def load(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def mainFrame(self, /) -> PySide6.QtWebEngineCore.QWebEngineFrame: ...
    @typing.overload
    def printToPdf(self, filePath: str, /, layout: PySide6.QtGui.QPageLayout = ..., ranges: PySide6.QtGui.QPageRanges = ...) -> None: ...
    @typing.overload
    def printToPdf(self, resultCallback: collections.abc.Callable[..., typing.Any], /, pageLayout: PySide6.QtGui.QPageLayout = ..., ranges: PySide6.QtGui.QPageRanges = ...) -> None: ...
    def profile(self, /) -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def recentlyAudible(self, /) -> bool: ...
    def recommendedState(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState: ...
    def renderProcessPid(self, /) -> int: ...
    def replaceMisspelledWord(self, replacement: str, /) -> None: ...
    def requestedUrl(self, /) -> PySide6.QtCore.QUrl: ...
    @typing.overload
    def runJavaScript(self, scriptSource: str, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    @typing.overload
    def runJavaScript(self, scriptSource: str, /, worldId: int | None = ..., resultCallback: collections.abc.Callable[..., typing.Any] = ...) -> None: ...
    def save(self, filePath: str, /, format: PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat = ...) -> None: ...
    def scripts(self, /) -> PySide6.QtWebEngineCore.QWebEngineScriptCollection: ...
    def scrollPosition(self, /) -> PySide6.QtCore.QPointF: ...
    def selectedText(self, /) -> str: ...
    def setAudioMuted(self, muted: bool, /) -> None: ...
    def setBackgroundColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setContent(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, mimeType: str = ..., baseUrl: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def setDevToolsPage(self, page: PySide6.QtWebEngineCore.QWebEnginePage, /) -> None: ...
    def setFeaturePermission(self, securityOrigin: PySide6.QtCore.QUrl | str, feature: PySide6.QtWebEngineCore.QWebEnginePage.Feature, policy: PySide6.QtWebEngineCore.QWebEnginePage.PermissionPolicy, /) -> None: ...
    def setHtml(self, html: str, /, baseUrl: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def setInspectedPage(self, page: PySide6.QtWebEngineCore.QWebEnginePage, /) -> None: ...
    def setLifecycleState(self, state: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState, /) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setUrlRequestInterceptor(self, interceptor: PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor, /) -> None: ...
    def setVisible(self, visible: bool, /) -> None: ...
    def setWebChannel(self, arg__1: PySide6.QtWebChannel.QWebChannel, /, worldId: int | None = ...) -> None: ...
    def setZoomFactor(self, factor: float, /) -> None: ...
    def settings(self, /) -> PySide6.QtWebEngineCore.QWebEngineSettings: ...
    def title(self, /) -> str: ...
    def toHtml(self, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def toPlainText(self, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def triggerAction(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction, /, checked: bool = ...) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...
    def webChannel(self, /) -> PySide6.QtWebChannel.QWebChannel: ...
    def zoomFactor(self, /) -> float: ...


class QWebEnginePermission(Shiboken.Object):

    class PermissionType(enum.Enum):

        Unsupported               = 0x0
        MediaAudioCapture         = 0x1
        MediaVideoCapture         = 0x2
        MediaAudioVideoCapture    = 0x3
        DesktopVideoCapture       = 0x4
        DesktopAudioVideoCapture  = 0x5
        MouseLock                 = 0x6
        Notifications             = 0x7
        Geolocation               = 0x8
        ClipboardReadWrite        = 0x9
        LocalFontsAccess          = 0xa

    class State(enum.Enum):

        Invalid                   = 0x0
        Ask                       = 0x1
        Granted                   = 0x2
        Denied                    = 0x3


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEnginePermission, /, *, origin: PySide6.QtCore.QUrl | None = ..., permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType | None = ..., state: PySide6.QtWebEngineCore.QWebEnginePermission.State | None = ..., isValid: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, origin: PySide6.QtCore.QUrl | None = ..., permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType | None = ..., state: PySide6.QtWebEngineCore.QWebEnginePermission.State | None = ..., isValid: bool | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtWebEngineCore.QWebEnginePermission, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtWebEngineCore.QWebEnginePermission, /) -> bool: ...
    def deny(self, /) -> None: ...
    def grant(self, /) -> None: ...
    @staticmethod
    def isPersistent(permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def permissionType(self, /) -> PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType: ...
    def reset(self, /) -> None: ...
    def state(self, /) -> PySide6.QtWebEngineCore.QWebEnginePermission.State: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEnginePermission, /) -> None: ...


class QWebEngineProfile(PySide6.QtCore.QObject):

    clearHttpCacheCompleted  : typing.ClassVar[Signal] = ... # clearHttpCacheCompleted()
    downloadRequested        : typing.ClassVar[Signal] = ... # downloadRequested(QWebEngineDownloadRequest*)

    class HttpCacheType(enum.Enum):

        MemoryHttpCache           = 0x0
        DiskHttpCache             = 0x1
        NoCache                   = 0x2

    class PersistentCookiesPolicy(enum.Enum):

        NoPersistentCookies       = 0x0
        AllowPersistentCookies    = 0x1
        ForcePersistentCookies    = 0x2
        OnlyPersistentCookies     = 0x3

    class PersistentPermissionsPolicy(enum.Enum):

        AskEveryTime              = 0x0
        StoreInMemory             = 0x1
        StoreOnDisk               = 0x2


    @typing.overload
    def __init__(self, name: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def additionalTrustedCertificates(self, /) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def cachePath(self, /) -> str: ...
    def clearAllVisitedLinks(self, /) -> None: ...
    def clearHttpCache(self, /) -> None: ...
    def clearVisitedLinks(self, urls: collections.abc.Sequence[PySide6.QtCore.QUrl], /) -> None: ...
    def clientCertificateStore(self, /) -> PySide6.QtWebEngineCore.QWebEngineClientCertificateStore: ...
    def clientHints(self, /) -> PySide6.QtWebEngineCore.QWebEngineClientHints: ...
    def cookieStore(self, /) -> PySide6.QtWebEngineCore.QWebEngineCookieStore: ...
    @staticmethod
    def defaultProfile() -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def downloadPath(self, /) -> str: ...
    def extensionManager(self, /) -> PySide6.QtWebEngineCore.QWebEngineExtensionManager: ...
    def httpAcceptLanguage(self, /) -> str: ...
    def httpCacheMaximumSize(self, /) -> int: ...
    def httpCacheType(self, /) -> PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType: ...
    def httpUserAgent(self, /) -> str: ...
    def installUrlSchemeHandler(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, arg__2: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler, /) -> None: ...
    def isOffTheRecord(self, /) -> bool: ...
    def isPushServiceEnabled(self, /) -> bool: ...
    def isSpellCheckEnabled(self, /) -> bool: ...
    def listAllPermissions(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def listPermissionsForOrigin(self, securityOrigin: PySide6.QtCore.QUrl | str, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def listPermissionsForPermissionType(self, permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def persistentCookiesPolicy(self, /) -> PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy: ...
    def persistentPermissionsPolicy(self, /) -> PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy: ...
    def persistentStoragePath(self, /) -> str: ...
    def queryPermission(self, securityOrigin: PySide6.QtCore.QUrl | str, permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType, /) -> PySide6.QtWebEngineCore.QWebEnginePermission: ...
    def removeAllUrlSchemeHandlers(self, /) -> None: ...
    def removeUrlScheme(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def removeUrlSchemeHandler(self, arg__1: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler, /) -> None: ...
    def scripts(self, /) -> PySide6.QtWebEngineCore.QWebEngineScriptCollection: ...
    def setCachePath(self, path: str, /) -> None: ...
    def setDownloadPath(self, path: str, /) -> None: ...
    def setHttpAcceptLanguage(self, httpAcceptLanguage: str, /) -> None: ...
    def setHttpCacheMaximumSize(self, maxSize: int, /) -> None: ...
    def setHttpCacheType(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType, /) -> None: ...
    def setHttpUserAgent(self, userAgent: str, /) -> None: ...
    def setNotificationPresenter(self, notificationPresenter: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def setPersistentCookiesPolicy(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy, /) -> None: ...
    def setPersistentPermissionsPolicy(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy, /) -> None: ...
    def setPersistentStoragePath(self, path: str, /) -> None: ...
    def setPushServiceEnabled(self, enabled: bool, /) -> None: ...
    def setSpellCheckEnabled(self, enabled: bool, /) -> None: ...
    def setSpellCheckLanguages(self, languages: collections.abc.Sequence[str], /) -> None: ...
    def setUrlRequestInterceptor(self, interceptor: PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor, /) -> None: ...
    def settings(self, /) -> PySide6.QtWebEngineCore.QWebEngineSettings: ...
    def spellCheckLanguages(self, /) -> typing.List[str]: ...
    def storageName(self, /) -> str: ...
    def urlSchemeHandler(self, arg__1: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler: ...
    def visitedLinksContainsUrl(self, url: PySide6.QtCore.QUrl | str, /) -> bool: ...


class QWebEngineProfileBuilder(Shiboken.Object):

    def __init__(self, /) -> None: ...

    @staticmethod
    def createOffTheRecordProfile(parent: PySide6.QtCore.QObject | None = ...) -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def createProfile(self, storageName: str, /, parent: PySide6.QtCore.QObject | None = ...) -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def setAdditionalTrustedCertificates(self, additionalTrustedCertificates: collections.abc.Sequence[PySide6.QtNetwork.QSslCertificate], /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setCachePath(self, path: str, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setHttpCacheMaximumSize(self, maxSizeInBytes: int, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setHttpCacheType(self, httpCacheType: PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setPersistentCookiesPolicy(self, persistentCookiesPolicy: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setPersistentPermissionsPolicy(self, persistentPermissionPolicy: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...
    def setPersistentStoragePath(self, path: str, /) -> PySide6.QtWebEngineCore.QWebEngineProfileBuilder: ...


class QWebEngineQuotaRequest(Shiboken.Object):

    def __init__(self, /, *, origin: PySide6.QtCore.QUrl | None = ..., requestedSize: int | None = ...) -> None: ...

    def __eq__(self, arg__1: PySide6.QtWebEngineCore.QWebEngineQuotaRequest, /) -> bool: ...
    def __ne__(self, arg__1: PySide6.QtWebEngineCore.QWebEngineQuotaRequest, /) -> bool: ...
    def accept(self, /) -> None: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def reject(self, /) -> None: ...
    def requestedSize(self, /) -> int: ...


class QWebEngineRegisterProtocolHandlerRequest(Shiboken.Object):

    @typing.overload
    def __init__(self, QWebEngineRegisterProtocolHandlerRequest: PySide6.QtWebEngineCore.QWebEngineRegisterProtocolHandlerRequest, /, *, origin: PySide6.QtCore.QUrl | None = ..., scheme: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, origin: PySide6.QtCore.QUrl | None = ..., scheme: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, that: PySide6.QtWebEngineCore.QWebEngineRegisterProtocolHandlerRequest, /) -> bool: ...
    def __ne__(self, that: PySide6.QtWebEngineCore.QWebEngineRegisterProtocolHandlerRequest, /) -> bool: ...
    def accept(self, /) -> None: ...
    def origin(self, /) -> PySide6.QtCore.QUrl: ...
    def reject(self, /) -> None: ...
    def scheme(self, /) -> str: ...


class QWebEngineScript(Shiboken.Object):

    class InjectionPoint(enum.Enum):

        Deferred                  = 0x0
        DocumentReady             = 0x1
        DocumentCreation          = 0x2

    class ScriptWorldId(enum.IntEnum):

        MainWorld                 = 0x0
        ApplicationWorld          = 0x1
        UserWorld                 = 0x2


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineScript, /, *, name: str | None = ..., sourceUrl: PySide6.QtCore.QUrl | None = ..., sourceCode: str | None = ..., injectionPoint: PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint | None = ..., worldId: int | None = ..., runsOnSubFrames: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, name: str | None = ..., sourceUrl: PySide6.QtCore.QUrl | None = ..., sourceCode: str | None = ..., injectionPoint: PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint | None = ..., worldId: int | None = ..., runsOnSubFrames: bool | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtWebEngineCore.QWebEngineScript, /) -> bool: ...
    def __ne__(self, other: PySide6.QtWebEngineCore.QWebEngineScript, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def injectionPoint(self, /) -> PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint: ...
    def name(self, /) -> str: ...
    def runsOnSubFrames(self, /) -> bool: ...
    def setInjectionPoint(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint, /) -> None: ...
    def setName(self, arg__1: str, /) -> None: ...
    def setRunsOnSubFrames(self, on: bool, /) -> None: ...
    def setSourceCode(self, arg__1: str, /) -> None: ...
    def setSourceUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setWorldId(self, arg__1: int, /) -> None: ...
    def sourceCode(self, /) -> str: ...
    def sourceUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEngineScript, /) -> None: ...
    def worldId(self, /) -> int: ...


class QWebEngineScriptCollection(Shiboken.Object):
    def clear(self, /) -> None: ...
    def contains(self, value: PySide6.QtWebEngineCore.QWebEngineScript, /) -> bool: ...
    def count(self, /) -> int: ...
    def find(self, name: str, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineScript]: ...
    @typing.overload
    def insert(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript, /) -> None: ...
    @typing.overload
    def insert(self, list: collections.abc.Sequence[PySide6.QtWebEngineCore.QWebEngineScript], /) -> None: ...
    def isEmpty(self, /) -> bool: ...
    def remove(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript, /) -> bool: ...
    def toList(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEngineScript]: ...


class QWebEngineSettings(Shiboken.Object):

    class FontFamily(enum.Enum):

        StandardFont              = 0x0
        FixedFont                 = 0x1
        SerifFont                 = 0x2
        SansSerifFont             = 0x3
        CursiveFont               = 0x4
        FantasyFont               = 0x5
        PictographFont            = 0x6

    class FontSize(enum.Enum):

        MinimumFontSize           = 0x0
        MinimumLogicalFontSize    = 0x1
        DefaultFontSize           = 0x2
        DefaultFixedFontSize      = 0x3

    class ImageAnimationPolicy(enum.Enum):

        Inherited                 = 0x0
        Allow                     = 0x1
        AnimateOnce               = 0x2
        Disallow                  = 0x3

    class UnknownUrlSchemePolicy(enum.Enum):

        InheritedUnknownUrlSchemePolicy = 0x0
        DisallowUnknownUrlSchemes = 0x1
        AllowUnknownUrlSchemesFromUserInteraction = 0x2
        AllowAllUnknownUrlSchemes = 0x3

    class WebAttribute(enum.Enum):

        AutoLoadImages            = 0x0
        JavascriptEnabled         = 0x1
        JavascriptCanOpenWindows  = 0x2
        JavascriptCanAccessClipboard = 0x3
        LinksIncludedInFocusChain = 0x4
        LocalStorageEnabled       = 0x5
        LocalContentCanAccessRemoteUrls = 0x6
        XSSAuditingEnabled        = 0x7
        SpatialNavigationEnabled  = 0x8
        LocalContentCanAccessFileUrls = 0x9
        HyperlinkAuditingEnabled  = 0xa
        ScrollAnimatorEnabled     = 0xb
        ErrorPageEnabled          = 0xc
        PluginsEnabled            = 0xd
        FullScreenSupportEnabled  = 0xe
        ScreenCaptureEnabled      = 0xf
        WebGLEnabled              = 0x10
        Accelerated2dCanvasEnabled = 0x11
        AutoLoadIconsForPage      = 0x12
        TouchIconsEnabled         = 0x13
        FocusOnNavigationEnabled  = 0x14
        PrintElementBackgrounds   = 0x15
        AllowRunningInsecureContent = 0x16
        AllowGeolocationOnInsecureOrigins = 0x17
        AllowWindowActivationFromJavaScript = 0x18
        ShowScrollBars            = 0x19
        PlaybackRequiresUserGesture = 0x1a
        WebRTCPublicInterfacesOnly = 0x1b
        JavascriptCanPaste        = 0x1c
        DnsPrefetchEnabled        = 0x1d
        PdfViewerEnabled          = 0x1e
        NavigateOnDropEnabled     = 0x1f
        ReadingFromCanvasEnabled  = 0x20
        ForceDarkMode             = 0x21
        PrintHeaderAndFooter      = 0x22
        PreferCSSMarginsForPrinting = 0x23
        TouchEventsApiEnabled     = 0x24
        BackForwardCacheEnabled   = 0x25
        TrimAccessibilityIdentifiers = 0x26


    def defaultTextEncoding(self, /) -> str: ...
    def fontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily, /) -> str: ...
    def fontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize, /) -> int: ...
    def imageAnimationPolicy(self, /) -> PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy: ...
    def resetAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute, /) -> None: ...
    def resetFontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily, /) -> None: ...
    def resetFontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize, /) -> None: ...
    def resetImageAnimationPolicy(self, /) -> None: ...
    def resetUnknownUrlSchemePolicy(self, /) -> None: ...
    def setAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute, on: bool, /) -> None: ...
    def setDefaultTextEncoding(self, encoding: str, /) -> None: ...
    def setFontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily, family: str, /) -> None: ...
    def setFontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize, size: int, /) -> None: ...
    def setImageAnimationPolicy(self, policy: PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy, /) -> None: ...
    def setUnknownUrlSchemePolicy(self, policy: PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy, /) -> None: ...
    def testAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute, /) -> bool: ...
    def unknownUrlSchemePolicy(self, /) -> PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy: ...


class QWebEngineUrlRequestInfo(Shiboken.Object):

    class NavigationType(enum.Enum):

        NavigationTypeLink        = 0x0
        NavigationTypeTyped       = 0x1
        NavigationTypeFormSubmitted = 0x2
        NavigationTypeBackForward = 0x3
        NavigationTypeReload      = 0x4
        NavigationTypeOther       = 0x5
        NavigationTypeRedirect    = 0x6

    class ResourceType(enum.Enum):

        ResourceTypeMainFrame     = 0x0
        ResourceTypeSubFrame      = 0x1
        ResourceTypeStylesheet    = 0x2
        ResourceTypeScript        = 0x3
        ResourceTypeImage         = 0x4
        ResourceTypeFontResource  = 0x5
        ResourceTypeSubResource   = 0x6
        ResourceTypeObject        = 0x7
        ResourceTypeMedia         = 0x8
        ResourceTypeWorker        = 0x9
        ResourceTypeSharedWorker  = 0xa
        ResourceTypePrefetch      = 0xb
        ResourceTypeFavicon       = 0xc
        ResourceTypeXhr           = 0xd
        ResourceTypePing          = 0xe
        ResourceTypeServiceWorker = 0xf
        ResourceTypeCspReport     = 0x10
        ResourceTypePluginResource = 0x11
        ResourceTypeNavigationPreloadMainFrame = 0x13
        ResourceTypeNavigationPreloadSubFrame = 0x14
        ResourceTypeJson          = 0x15
        ResourceTypeLast          = 0x15
        ResourceTypeWebSocket     = 0xfe
        ResourceTypeUnknown       = 0xff


    def block(self, shouldBlock: bool, /) -> None: ...
    def changed(self, /) -> bool: ...
    def firstPartyUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def httpHeaders(self, /) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def initiator(self, /) -> PySide6.QtCore.QUrl: ...
    def isDownload(self, /) -> bool: ...
    def navigationType(self, /) -> PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo.NavigationType: ...
    def redirect(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def requestBody(self, /) -> PySide6.QtCore.QIODevice: ...
    def requestMethod(self, /) -> PySide6.QtCore.QByteArray: ...
    def requestUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def resourceType(self, /) -> PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo.ResourceType: ...
    def setHttpHeader(self, name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, value: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...


class QWebEngineUrlRequestInterceptor(PySide6.QtCore.QObject):

    def __init__(self, /, p: PySide6.QtCore.QObject | None = ...) -> None: ...

    def interceptRequest(self, info: PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo, /) -> None: ...


class QWebEngineUrlRequestJob(PySide6.QtCore.QObject):

    class Error(enum.Enum):

        NoError                   = 0x0
        UrlNotFound               = 0x1
        UrlInvalid                = 0x2
        RequestAborted            = 0x3
        RequestDenied             = 0x4
        RequestFailed             = 0x5


    def fail(self, error: PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.Error, /) -> None: ...
    def initiator(self, /) -> PySide6.QtCore.QUrl: ...
    def redirect(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def reply(self, contentType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, device: PySide6.QtCore.QIODevice, /) -> None: ...
    def requestBody(self, /) -> PySide6.QtCore.QIODevice: ...
    def requestHeaders(self, /) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def requestMethod(self, /) -> PySide6.QtCore.QByteArray: ...
    def requestUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def setAdditionalResponseHeaders(self, additionalResponseHeaders: typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray], /) -> None: ...


class QWebEngineUrlScheme(Shiboken.Object):

    class Flag(enum.Flag):

        SecureScheme              = 0x1
        LocalScheme               = 0x2
        LocalAccessAllowed        = 0x4
        NoAccessAllowed           = 0x8
        ServiceWorkersAllowed     = 0x10
        ViewSourceAllowed         = 0x20
        ContentSecurityPolicyIgnored = 0x40
        CorsEnabled               = 0x80
        FetchApiAllowed           = 0x100

    class SpecialPort(enum.Enum):

        PortUnspecified           = -1

    class Syntax(enum.Enum):

        HostPortAndUserInformation = 0x0
        HostAndPort               = 0x1
        Host                      = 0x2
        Path                      = 0x3


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, that: PySide6.QtWebEngineCore.QWebEngineUrlScheme, /) -> None: ...
    @typing.overload
    def __init__(self, name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, that: PySide6.QtWebEngineCore.QWebEngineUrlScheme, /) -> bool: ...
    def __ne__(self, that: PySide6.QtWebEngineCore.QWebEngineUrlScheme, /) -> bool: ...
    def defaultPort(self, /) -> int: ...
    def flags(self, /) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag: ...
    def name(self, /) -> PySide6.QtCore.QByteArray: ...
    @staticmethod
    def registerScheme(scheme: PySide6.QtWebEngineCore.QWebEngineUrlScheme, /) -> None: ...
    @staticmethod
    def schemeByName(name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme: ...
    def setDefaultPort(self, newValue: int, /) -> None: ...
    def setFlags(self, newValue: PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag, /) -> None: ...
    def setName(self, newValue: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setSyntax(self, newValue: PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax, /) -> None: ...
    def syntax(self, /) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax: ...


class QWebEngineUrlSchemeHandler(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def requestStarted(self, arg__1: PySide6.QtWebEngineCore.QWebEngineUrlRequestJob, /) -> None: ...


class QWebEngineWebAuthPinRequest(Shiboken.Object):

    error                     = ...  # type: PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.PinEntryError
    minPinLength              = ...  # type: int
    reason                    = ...  # type: PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.PinEntryReason
    remainingAttempts         = ...  # type: int

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QWebEngineWebAuthPinRequest: PySide6.QtWebEngineCore.QWebEngineWebAuthPinRequest, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...


class QWebEngineWebAuthUxRequest(PySide6.QtCore.QObject):

    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QWebEngineWebAuthUxRequest::WebAuthUxState)

    class PinEntryError(enum.Enum):

        NoError                   = 0x0
        InternalUvLocked          = 0x1
        WrongPin                  = 0x2
        TooShort                  = 0x3
        InvalidCharacters         = 0x4
        SameAsCurrentPin          = 0x5

    class PinEntryReason(enum.Enum):

        Set                       = 0x0
        Change                    = 0x1
        Challenge                 = 0x2

    class RequestFailureReason(enum.Enum):

        Timeout                   = 0x0
        KeyNotRegistered          = 0x1
        KeyAlreadyRegistered      = 0x2
        SoftPinBlock              = 0x3
        HardPinBlock              = 0x4
        AuthenticatorRemovedDuringPinEntry = 0x5
        AuthenticatorMissingResidentKeys = 0x6
        AuthenticatorMissingUserVerification = 0x7
        AuthenticatorMissingLargeBlob = 0x8
        NoCommonAlgorithms        = 0x9
        StorageFull               = 0xa
        UserConsentDenied         = 0xb
        WinUserCancelled          = 0xc

    class WebAuthUxState(enum.Enum):

        NotStarted                = 0x0
        SelectAccount             = 0x1
        CollectPin                = 0x2
        FinishTokenCollection     = 0x3
        RequestFailed             = 0x4
        Cancelled                 = 0x5
        Completed                 = 0x6


    def cancel(self, /) -> None: ...
    def pinRequest(self, /) -> PySide6.QtWebEngineCore.QWebEngineWebAuthPinRequest: ...
    def relyingPartyId(self, /) -> str: ...
    def requestFailureReason(self, /) -> PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.RequestFailureReason: ...
    def retry(self, /) -> None: ...
    def setPin(self, pin: str, /) -> None: ...
    def setSelectedAccount(self, selectedAccount: str, /) -> None: ...
    def state(self, /) -> PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.WebAuthUxState: ...
    def userNames(self, /) -> typing.List[str]: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...
def qWebEngineChromiumSecurityPatchVersion() -> bytes | bytearray | memoryview: ...
def qWebEngineChromiumVersion() -> bytes | bytearray | memoryview: ...
def qWebEngineVersion() -> bytes | bytearray | memoryview: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtConcurrent, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtConcurrent`

import PySide6.QtConcurrent
import PySide6.QtCore

import enum
import typing
import collections.abc
from shiboken6 import Shiboken


class QFutureQString(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QFutureQString: PySide6.QtConcurrent.QFutureQString, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def cancel(self, /) -> None: ...
    def cancelChain(self, /) -> None: ...
    def isCanceled(self, /) -> bool: ...
    def isFinished(self, /) -> bool: ...
    def isPaused(self, /) -> bool: ...
    def isRunning(self, /) -> bool: ...
    def isStarted(self, /) -> bool: ...
    def isSuspended(self, /) -> bool: ...
    def isSuspending(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def pause(self, /) -> None: ...
    def progressMaximum(self, /) -> int: ...
    def progressMinimum(self, /) -> int: ...
    def progressText(self, /) -> str: ...
    def progressValue(self, /) -> int: ...
    def resultCount(self, /) -> int: ...
    def resume(self, /) -> None: ...
    def setPaused(self, paused: bool, /) -> None: ...
    def setSuspended(self, suspend: bool, /) -> None: ...
    def suspend(self, /) -> None: ...
    def togglePaused(self, /) -> None: ...
    def toggleSuspended(self, /) -> None: ...
    def waitForFinished(self, /) -> None: ...


class QFutureVoid(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QFutureVoid: PySide6.QtConcurrent.QFutureVoid, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def cancel(self, /) -> None: ...
    def cancelChain(self, /) -> None: ...
    def isCanceled(self, /) -> bool: ...
    def isFinished(self, /) -> bool: ...
    def isPaused(self, /) -> bool: ...
    def isRunning(self, /) -> bool: ...
    def isStarted(self, /) -> bool: ...
    def isSuspended(self, /) -> bool: ...
    def isSuspending(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def pause(self, /) -> None: ...
    def progressMaximum(self, /) -> int: ...
    def progressMinimum(self, /) -> int: ...
    def progressText(self, /) -> str: ...
    def progressValue(self, /) -> int: ...
    def resultCount(self, /) -> int: ...
    def resume(self, /) -> None: ...
    def setPaused(self, paused: bool, /) -> None: ...
    def setSuspended(self, suspend: bool, /) -> None: ...
    def suspend(self, /) -> None: ...
    def togglePaused(self, /) -> None: ...
    def toggleSuspended(self, /) -> None: ...
    def waitForFinished(self, /) -> None: ...


class QFutureWatcherQString(PySide6.QtCore.QObject):

    def __init__(self, /, _parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def future(self, /) -> PySide6.QtConcurrent.QFutureQString: ...
    def setFuture(self, future: PySide6.QtConcurrent.QFutureQString, /) -> None: ...


class QFutureWatcherVoid(PySide6.QtCore.QObject):

    def __init__(self, /, _parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QIntList: ...


class QtConcurrent(Shiboken.Object):

    class FutureResult(enum.Enum):

        Ignore                    = 0x0

    class ReduceOption(enum.Flag):

        UnorderedReduce           = 0x1
        OrderedReduce             = 0x2
        SequentialReduce          = 0x4

    class ThreadFunctionResult(enum.Enum):

        ThrottleThread            = 0x0
        ThreadFinished            = 0x1


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2023 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations

from PySide6.QtCore import (QCoreApplication, QDateTime, QDeadlineTimer,
                            QEventLoop, QObject, QTimer, QThread, Slot)

from . import futures
from . import tasks

from typing import Any, Callable, TypeVar

import asyncio
import collections.abc
import concurrent.futures
import contextvars
import enum
import os
import signal
import socket
import subprocess
import warnings

__all__ = [
    "QAsyncioEventLoopPolicy", "QAsyncioEventLoop",
    "QAsyncioHandle", "QAsyncioTimerHandle",
]

from typing import TYPE_CHECKING

_T = TypeVar("_T")

if TYPE_CHECKING:
    try:
        from typing import TypeVarTuple, Unpack
    except ImportError:
        from typing_extensions import TypeVarTuple, Unpack  # type: ignore

    _Ts = TypeVarTuple("_Ts")
    Context = contextvars.Context   # type: ignore
else:
    _Ts = None  # type: ignore
    Context = contextvars.Context


class QAsyncioExecutorWrapper(QObject):
    """
    Executors in asyncio allow running synchronous code in a separate thread or
    process without blocking the event loop or interrupting the asynchronous
    program flow. Callables are scheduled for execution by calling submit() or
    map() on an executor object.

    Executors require a bit of extra work for QtAsyncio, as we can't use
    naked Python threads; instead, we must make sure that the thread created
    by executor.submit() has an event loop. This is achieved by not submitting
    the callable directly, but a small wrapper that attaches a QEventLoop to
    the executor thread, and then creates a zero-delay singleshot timer to push
    the actual callable for the executor into this new event loop.
    """
    def __init__(self, func: Callable[[Unpack[_Ts]], Any], *args: Unpack[_Ts]) -> None:
        super().__init__()
        self._loop: QEventLoop
        self._func = func
        self._args = args
        self._result: Any = None
        self._exception: BaseException | None = None

    def _cb(self):
        try:
            # Call the synchronous callable that we submitted with submit() or
            # map().
            self._result = self._func(*self._args)
        except BaseException as e:
            self._exception = e
        self._loop.exit()

    def do(self) -> Any:
        # This creates a new event loop and dispatcher for the thread, if not
        # already created.
        self._loop = QEventLoop()
        asyncio.events._set_running_loop(self._loop)

        # The do() function will always be executed from the new executor
        # thread and never from outside, so using the overload without the
        # context argument is sufficient.
        QTimer.singleShot(0, lambda: self._cb())

        self._loop.exec()
        if self._exception is not None:
            raise self._exception
        return self._result

    def exit(self):
        self._loop.exit()


class QAsyncioEventLoopPolicy(asyncio.AbstractEventLoopPolicy):
    """
    Event loop policies are expected to be deprecated with Python 3.13, with
    subsequent removal in Python 3.15. At that point, part of the current
    logic of the QAsyncioEventLoopPolicy constructor will have to be moved
    to QtAsyncio.run() and/or to a loop factory class (to be provided as an
    argument to asyncio.run()). In particular, this concerns the logic of
    setting up the QCoreApplication and the SIGINT handler.

    More details:
    https://discuss.python.org/t/removing-the-asyncio-policy-system-asyncio-set-event-loop-policy-in-python-3-15/37553
    """
    def __init__(self,
                 quit_qapp: bool = True,
                 handle_sigint: bool = False) -> None:
        super().__init__()
        self._application = QCoreApplication.instance() or QCoreApplication()

        # Configure whether the QCoreApplication at the core of QtAsyncio
        # should be shut down when asyncio finishes. A special case where one
        # would want to disable this is test suites that want to reuse a single
        # QCoreApplication instance across all unit tests, which would fail if
        # this instance is shut down every time.
        self._quit_qapp = quit_qapp

        self._event_loop: asyncio.AbstractEventLoop | None = None

        if handle_sigint:
            signal.signal(signal.SIGINT, signal.SIG_DFL)

    def get_event_loop(self) -> asyncio.AbstractEventLoop:
        if self._event_loop is None:
            self._event_loop = QAsyncioEventLoop(self._application, quit_qapp=self._quit_qapp)
        return self._event_loop

    def set_event_loop(self, loop: asyncio.AbstractEventLoop | None) -> None:
        self._event_loop = loop

    def new_event_loop(self) -> asyncio.AbstractEventLoop:
        return QAsyncioEventLoop(self._application, quit_qapp=self._quit_qapp)

    def get_child_watcher(self) -> "asyncio.AbstractChildWatcher":
        raise DeprecationWarning("Child watchers are deprecated since Python 3.12")

    def set_child_watcher(self, watcher: "asyncio.AbstractChildWatcher") -> None:
        raise DeprecationWarning("Child watchers are deprecated since Python 3.12")


class QAsyncioEventLoop(asyncio.BaseEventLoop, QObject):
    """
    Implements the asyncio API:
    https://docs.python.org/3/library/asyncio-eventloop.html
    """

    class ShutDownThread(QThread):
        """
        Used to shut down the default executor when calling
        shutdown_default_executor(). As the executor is a ThreadPoolExecutor,
        it must be shut down in a separate thread as all the threads from the
        thread pool must join, which we want to do without blocking the event
        loop.
        """

        def __init__(self, future: futures.QAsyncioFuture, loop: "QAsyncioEventLoop") -> None:
            super().__init__()
            self._future = future
            self._loop = loop
            self.started.connect(self.shutdown)

        def run(self) -> None:
            pass

        def shutdown(self) -> None:
            try:
                self._loop._default_executor.shutdown(wait=True)
                if not self._loop.is_closed():
                    self._loop.call_soon_threadsafe(self._future.set_result, None)
            except Exception as e:
                if not self._loop.is_closed():
                    self._loop.call_soon_threadsafe(self._future.set_exception, e)

    def __init__(self,
                 application: QCoreApplication, quit_qapp: bool = True) -> None:
        asyncio.BaseEventLoop.__init__(self)
        QObject.__init__(self)

        self._application: QCoreApplication = application

        # Configure whether the QCoreApplication at the core of QtAsyncio
        # should be shut down when asyncio finishes. A special case where one
        # would want to disable this is test suites that want to reuse a single
        # QCoreApplication instance across all unit tests, which would fail if
        # this instance is shut down every time.
        self._quit_qapp = quit_qapp

        self._thread = QThread.currentThread()

        self._closed = False

        # These two flags are used to determine whether the loop was stopped
        # from inside the loop (i.e., coroutine or callback called stop()) or
        # from outside the loop (i.e., the QApplication is being shut down, for
        # example, by the user closing the window or by calling
        # QApplication.quit()). The different cases can trigger slightly
        # different behaviors (see the comments where the flags are used).
        # There are two variables for this as in a third case the loop is still
        # running and both flags are False.
        self._quit_from_inside = False
        self._quit_from_outside = False

        # A set of all asynchronous generators that are currently running.
        self._asyncgens: set[collections.abc.AsyncGenerator] = set()

        # Starting with Python 3.11, this must be an instance of
        # ThreadPoolExecutor.
        self._default_executor = concurrent.futures.ThreadPoolExecutor()

        # The exception handler, if set with set_exception_handler(). The
        # exception handler is currently called in two places: One, if an
        # asynchonrous generator raises an exception when closed, and two, if
        # an exception is raised during the execution of a task. Currently, the
        # default exception handler just prints the exception to the console.
        self._exception_handler: Callable | None = self.default_exception_handler

        # The task factory, if set with set_task_factory(). Otherwise, a new
        # task is created with the QAsyncioTask constructor.
        self._task_factory: Callable | None = None

        # The future that is currently being awaited with run_until_complete().
        self._future_to_complete: futures.QAsyncioFuture | None = None

        self._debug = bool(os.getenv("PYTHONASYNCIODEBUG", False))

        self._application.aboutToQuit.connect(self._about_to_quit_cb)

    # Running and stopping the loop

    def _run_until_complete_cb(self, future: futures.QAsyncioFuture) -> None:
        """
        A callback that stops the loop when the future is done, used when
        running the loop with run_until_complete().
        """
        if not future.cancelled():
            if isinstance(future.exception(), (SystemExit, KeyboardInterrupt)):
                return
        future.get_loop().stop()

    def run_until_complete(self,
                           future: futures.QAsyncioFuture) -> Any:  # type: ignore[override]
        if self.is_closed():
            raise RuntimeError("Event loop is closed")
        if self.is_running():
            raise RuntimeError("Event loop is already running")

        arg_was_coro = not asyncio.futures.isfuture(future)
        future = asyncio.tasks.ensure_future(future, loop=self)  # type: ignore[assignment]
        future.add_done_callback(self._run_until_complete_cb)
        self._future_to_complete = future

        try:
            self.run_forever()
        except Exception as e:
            if arg_was_coro and future.done() and not future.cancelled():
                future.exception()
            raise e
        finally:
            future.remove_done_callback(self._run_until_complete_cb)
        if not future.done():
            raise RuntimeError("Event loop stopped before Future completed")

        return future.result()

    def run_forever(self) -> None:
        if self.is_closed():
            raise RuntimeError("Event loop is closed")
        if self.is_running():
            raise RuntimeError("Event loop is already running")
        asyncio.events._set_running_loop(self)
        self._application.exec()
        asyncio.events._set_running_loop(None)

    def _about_to_quit_cb(self):
        """ A callback for the aboutToQuit signal of the QCoreApplication. """
        if not self._quit_from_inside:
            # If the aboutToQuit signal is emitted, the user is closing the
            # application window or calling QApplication.quit(). In this case,
            # we want to close the event loop, and we consider this a quit from
            # outside the loop.
            self._quit_from_outside = True
            self.close()

    def stop(self) -> None:
        if self._future_to_complete is not None:
            if self._future_to_complete.done():
                self._future_to_complete = None
            else:
                # Do not stop the loop if there is a future still being awaited
                # with run_until_complete().
                return

        self._quit_from_inside = True

        # The user might want to keep the QApplication running after the event
        # event loop finishes, which they can control with the quit_qapp
        # argument.
        if self._quit_qapp:
            self._application.quit()

    def is_running(self) -> bool:
        return self._thread.loopLevel() > 0

    def is_closed(self) -> bool:
        return self._closed

    def close(self) -> None:
        if self.is_running() and not self._quit_from_outside:
            raise RuntimeError("Cannot close a running event loop")
        if self.is_closed():
            return
        if self._default_executor is not None:
            self._default_executor.shutdown(wait=False)
        self._closed = True

    async def shutdown_asyncgens(self) -> None:
        if not len(self._asyncgens):
            return

        results = await asyncio.tasks.gather(
            *[asyncgen.aclose() for asyncgen in self._asyncgens],
            return_exceptions=True)

        for result, asyncgen in zip(results, self._asyncgens):
            if isinstance(result, Exception):
                self.call_exception_handler({
                    "message": f"Closing asynchronous generator {asyncgen}"
                               f"raised an exception",
                    "exception": result,
                    "asyncgen": asyncgen})

        self._asyncgens.clear()

    async def shutdown_default_executor(self,  # type: ignore[override]
                                        timeout: int | float | None = None) -> None:
        shutdown_successful = False
        if timeout is not None:
            deadline_timer = QDeadlineTimer(int(timeout * 1000))
        else:
            deadline_timer = QDeadlineTimer(QDeadlineTimer.ForeverConstant.Forever)

        if self._default_executor is None:
            return
        future = self.create_future()
        thread = QAsyncioEventLoop.ShutDownThread(future, self)
        thread.start()
        try:
            await future
        finally:
            shutdown_successful = thread.wait(deadline_timer)

        if timeout is not None and not shutdown_successful:
            warnings.warn(
                f"Could not shutdown the default executor within {timeout} seconds",
                RuntimeWarning, stacklevel=2)
            self._default_executor.shutdown(wait=False)

    # Scheduling callbacks

    def _call_soon_impl(self, callback: Callable[[Unpack[_Ts]], object], *args: Unpack[_Ts],
                        context: Context | None = None,
                        is_threadsafe: bool | None = False) -> asyncio.Handle:
        return self._call_later_impl(0, callback, *args, context=context,
                                     is_threadsafe=is_threadsafe)

    def call_soon(self, callback: Callable[[Unpack[_Ts]], object], *args: Unpack[_Ts],
                  context: Context | None = None) -> asyncio.Handle:
        return self._call_soon_impl(callback, *args, context=context, is_threadsafe=False)

    def call_soon_threadsafe(self, callback: Callable[[Unpack[_Ts]], object], *args: Unpack[_Ts],
                             context: Context | None = None) -> asyncio.Handle:
        if self.is_closed():
            raise RuntimeError("Event loop is closed")
        if context is None:
            context = contextvars.copy_context()
        return self._call_soon_impl(callback, *args, context=context, is_threadsafe=True)

    def _call_later_impl(self, delay: float, callback: Callable[[Unpack[_Ts]], object],
                         *args: Unpack[_Ts], context: Context | None = None,
                         is_threadsafe: bool | None = False) -> asyncio.TimerHandle:
        if not isinstance(delay, (int, float)):
            raise TypeError("delay must be an int or float")
        return self._call_at_impl(self.time() + delay, callback, *args,
                                  context=context, is_threadsafe=is_threadsafe)

    def call_later(self, delay: float, callback: Callable[[Unpack[_Ts]], object],
                   *args: Unpack[_Ts], context: Context | None = None) -> asyncio.TimerHandle:
        return self._call_later_impl(delay, callback, *args, context=context, is_threadsafe=False)

    def _call_at_impl(self, when: float, callback: Callable[[Unpack[_Ts]], object],
                      *args: Unpack[_Ts], context: Context | None = None,
                      is_threadsafe: bool | None = False) -> asyncio.TimerHandle:
        """ All call_at() and call_later() methods map to this method. """
        if not isinstance(when, (int, float)):
            raise TypeError("when must be an int or float")
        return QAsyncioTimerHandle(when, callback, args, self, context, is_threadsafe=is_threadsafe)

    def call_at(self, when: float, callback: Callable[[Unpack[_Ts]], object],
                *args: Unpack[_Ts], context: Context | None = None) -> asyncio.TimerHandle:
        return self._call_at_impl(when, callback, *args, context=context, is_threadsafe=False)

    def time(self) -> float:
        return QDateTime.currentMSecsSinceEpoch() / 1000.0

    # Creating Futures and Tasks

    def create_future(self) -> futures.QAsyncioFuture:  # type: ignore[override]
        return futures.QAsyncioFuture(loop=self)

    def create_task(self,  # type: ignore[override]
                    coro: collections.abc.Generator | collections.abc.Coroutine,
                    *, name: str | None = None,
                    context: contextvars.Context | None = None) -> tasks.QAsyncioTask:
        if self._task_factory is None:
            task = tasks.QAsyncioTask(coro, loop=self, name=name, context=context)
        else:
            task = self._task_factory(self, coro, context=context)
            task.set_name(name)

        return task

    def set_task_factory(self, factory: Callable | None) -> None:
        if factory is not None and not callable(factory):
            raise TypeError("The task factory must be a callable or None")
        self._task_factory = factory

    def get_task_factory(self) -> Callable | None:
        return self._task_factory

    # Opening network connections

    async def create_connection(
            self, protocol_factory, host=None, port=None,
            *, ssl=None, family=0, proto=0,
            flags=0, sock=None, local_addr=None,
            server_hostname=None,
            ssl_handshake_timeout=None,
            ssl_shutdown_timeout=None,
            happy_eyeballs_delay=None, interleave=None):
        raise NotImplementedError("QAsyncioEventLoop.create_connection() is not implemented yet")

    async def create_datagram_endpoint(self, protocol_factory,
                                       local_addr=None, remote_addr=None, *,
                                       family=0, proto=0, flags=0,
                                       reuse_address=None, reuse_port=None,
                                       allow_broadcast=None, sock=None):
        raise NotImplementedError(
            "QAsyncioEventLoop.create_datagram_endpoint() is not implemented yet")

    async def create_unix_connection(
            self, protocol_factory, path=None, *,
            ssl=None, sock=None,
            server_hostname=None,
            ssl_handshake_timeout=None,
            ssl_shutdown_timeout=None):
        raise NotImplementedError(
            "QAsyncioEventLoop.create_unix_connection() is not implemented yet")

    # Creating network servers

    async def create_server(
            self, protocol_factory, host=None, port=None,
            *, family=socket.AF_UNSPEC,
            flags=socket.AI_PASSIVE, sock=None, backlog=100,
            ssl=None, reuse_address=None, reuse_port=None,
            ssl_handshake_timeout=None,
            ssl_shutdown_timeout=None,
            start_serving=True):
        raise NotImplementedError("QAsyncioEventLoop.create_server() is not implemented yet")

    async def create_unix_server(
            self, protocol_factory, path=None, *,
            sock=None, backlog=100, ssl=None,
            ssl_handshake_timeout=None,
            ssl_shutdown_timeout=None,
            start_serving=True):
        raise NotImplementedError("QAsyncioEventLoop.create_unix_server() is not implemented yet")

    async def connect_accepted_socket(
            self, protocol_factory, sock,
            *, ssl=None,
            ssl_handshake_timeout=None,
            ssl_shutdown_timeout=None):
        raise NotImplementedError(
            "QAsyncioEventLoop.connect_accepted_socket() is not implemented yet")

    # Transferring files

    async def sendfile(self, transport, file, offset=0, count=None,
                       *, fallback=True):
        raise NotImplementedError("QAsyncioEventLoop.sendfile() is not implemented yet")

    # TLS Upgrade

    async def start_tls(self, transport, protocol, sslcontext, *,
                        server_side=False,
                        server_hostname=None,
                        ssl_handshake_timeout=None,
                        ssl_shutdown_timeout=None):
        raise NotImplementedError("QAsyncioEventLoop.start_tls() is not implemented yet")

    # Watching file descriptors

    def add_reader(self, fd, callback, *args):
        raise NotImplementedError("QAsyncioEventLoop.add_reader() is not implemented yet")

    def remove_reader(self, fd):
        raise NotImplementedError("QAsyncioEventLoop.remove_reader() is not implemented yet")

    def add_writer(self, fd, callback, *args):
        raise NotImplementedError("QAsyncioEventLoop.add_writer() is not implemented yet")

    def remove_writer(self, fd):
        raise NotImplementedError("QAsyncioEventLoop.remove_writer() is not implemented yet")

    # Working with socket objects directly

    async def sock_recv(self, sock, nbytes):
        raise NotImplementedError("QAsyncioEventLoop.sock_recv() is not implemented yet")

    async def sock_recv_into(self, sock, buf):
        raise NotImplementedError("QAsyncioEventLoop.sock_recv_into() is not implemented yet")

    async def sock_recvfrom(self, sock, bufsize):
        raise NotImplementedError("QAsyncioEventLoop.sock_recvfrom() is not implemented yet")

    async def sock_recvfrom_into(self, sock, buf, nbytes=0):
        raise NotImplementedError("QAsyncioEventLoop.sock_recvfrom_into() is not implemented yet")

    async def sock_sendall(self, sock, data):
        raise NotImplementedError("QAsyncioEventLoop.sock_sendall() is not implemented yet")

    async def sock_sendto(self, sock, data, address):
        raise NotImplementedError("QAsyncioEventLoop.sock_sendto() is not implemented yet")

    async def sock_connect(self, sock, address):
        raise NotImplementedError("QAsyncioEventLoop.sock_connect() is not implemented yet")

    async def sock_accept(self, sock):
        raise NotImplementedError("QAsyncioEventLoop.sock_accept() is not implemented yet")

    async def sock_sendfile(self, sock, file, offset=0, count=None, *,
                            fallback=None):
        raise NotImplementedError("QAsyncioEventLoop.sock_sendfile() is not implemented yet")

    # DNS

    async def getaddrinfo(self, host, port, *,
                          family=0, type=0, proto=0, flags=0):
        raise NotImplementedError("QAsyncioEventLoop.getaddrinfo() is not implemented yet")

    async def getnameinfo(self, sockaddr, flags=0):
        raise NotImplementedError("QAsyncioEventLoop.getnameinfo() is not implemented yet")

    # Working with pipes

    async def connect_read_pipe(self, protocol_factory, pipe):
        raise NotImplementedError("QAsyncioEventLoop.connect_read_pipe() is not implemented yet")

    async def connect_write_pipe(self, protocol_factory, pipe):
        raise NotImplementedError("QAsyncioEventLoop.connect_write_pipe() is not implemented yet")

    # Unix signals

    def add_signal_handler(self, sig, callback, *args):
        raise NotImplementedError("QAsyncioEventLoop.add_signal_handler() is not implemented yet")

    def remove_signal_handler(self, sig):
        raise NotImplementedError(
            "QAsyncioEventLoop.remove_signal_handler() is not implemented yet")

    # Executing code in thread or process pools

    def run_in_executor(self, executor: concurrent.futures.ThreadPoolExecutor | None,
                        func: Callable[[Unpack[_Ts]], _T],
                        *args: Unpack[_Ts]) -> asyncio.Future[_T]:
        if self.is_closed():
            raise RuntimeError("Event loop is closed")
        if executor is None:
            executor = self._default_executor

        # Executors require a bit of extra work for QtAsyncio, as we can't use
        # naked Python threads; instead, we must make sure that the thread
        # created by executor.submit() has an event loop. This is achieved by
        # not submitting the callable directly, but a small wrapper that
        # attaches a QEventLoop to the executor thread, and then pushes the
        # actual callable for the executor into this new event loop.
        wrapper = QAsyncioExecutorWrapper(func, *args)
        return asyncio.futures.wrap_future(executor.submit(wrapper.do), loop=self)

    def set_default_executor(self,
                             executor: concurrent.futures.ThreadPoolExecutor | None) -> None:
        if not isinstance(executor, concurrent.futures.ThreadPoolExecutor):
            raise TypeError("The executor must be a ThreadPoolExecutor")
        self._default_executor = executor

    # Error Handling API

    def set_exception_handler(self, handler: Callable | None) -> None:
        if handler is not None and not callable(handler):
            raise TypeError("The handler must be a callable or None")
        self._exception_handler = handler

    def get_exception_handler(self) -> Callable | None:
        return self._exception_handler

    def default_exception_handler(self, context: dict[str, Any]) -> None:
        # TODO
        if context["message"]:
            print(f"{context['message']} from task {context['task']._name},"
                  "read the following traceback:")
            print(context["traceback"])

    def call_exception_handler(self, context: dict[str, Any]) -> None:
        if self._exception_handler is not None:
            self._exception_handler(context)

    # Enabling debug mode

    def get_debug(self) -> bool:
        # TODO: Part of the asyncio API but currently unused. More details:
        # https://docs.python.org/3/library/asyncio-dev.html#asyncio-debug-mode
        return self._debug

    def set_debug(self, enabled: bool) -> None:
        self._debug = enabled

    # Running subprocesses

    async def subprocess_exec(self, protocol_factory, *args,
                              stdin=subprocess.PIPE,
                              stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE,
                              **kwargs):
        raise NotImplementedError("QAsyncioEventLoop.subprocess_exec() is not implemented yet")

    async def subprocess_shell(self, protocol_factory, cmd, *,
                               stdin=subprocess.PIPE,
                               stdout=subprocess.PIPE,
                               stderr=subprocess.PIPE,
                               **kwargs):
        raise NotImplementedError("QAsyncioEventLoop.subprocess_shell() is not implemented yet")


class QAsyncioHandle():
    """
    The handle enqueues a callback to be executed by the event loop, and allows
    for this callback to be cancelled before it is executed. This callback will
    typically execute the step function for a task. This makes the handle one
    of the main components of asyncio.
    """
    class HandleState(enum.Enum):
        PENDING = enum.auto()
        CANCELLED = enum.auto()
        DONE = enum.auto()

    def __init__(self, callback: Callable, args: tuple,
                 loop: QAsyncioEventLoop, context: contextvars.Context | None,
                 is_threadsafe: bool | None = False) -> None:
        self._callback = callback
        self._cb_args = args  # renamed from _args to avoid conflict with TimerHandle._args
        self._loop = loop
        self._context = context
        self._is_threadsafe = is_threadsafe
        self._timeout = 0
        self._state = QAsyncioHandle.HandleState.PENDING
        self._start()

    def _start(self) -> None:
        self._schedule_event(self._timeout, lambda: self._cb())

    def _schedule_event(self, timeout: int, func: Callable) -> None:
        # Do not schedule events from asyncio when the app is quit from outside
        # the event loop, as this would cause events to be enqueued after the
        # event loop was destroyed.
        if not self._loop.is_closed() and not self._loop._quit_from_outside:
            if self._is_threadsafe:
                # This singleShot overload will push func into self._loop
                # instead of the current thread's loop. This allows scheduling
                # a callback from a different thread, which is necessary for
                # thread-safety.
                # https://docs.python.org/3/library/asyncio-dev.html#asyncio-multithreading
                QTimer.singleShot(timeout, self._loop, func)
            else:
                QTimer.singleShot(timeout, func)

    @Slot()
    def _cb(self) -> None:
        """
        A slot, enqueued into the event loop, that wraps around the actual
        callback, typically the step function of a task.
        """
        if self._state == QAsyncioHandle.HandleState.PENDING:
            if self._context is not None:
                self._context.run(self._callback, *self._cb_args)
            else:
                self._callback(*self._cb_args)
            self._state = QAsyncioHandle.HandleState.DONE

    def cancel(self) -> None:
        if self._state == QAsyncioHandle.HandleState.PENDING:
            # The old timer that was created in _start will still trigger but
            # _cb won't do anything, therefore the callback is effectively
            # cancelled.
            self._state = QAsyncioHandle.HandleState.CANCELLED

    def cancelled(self) -> bool:
        return self._state == QAsyncioHandle.HandleState.CANCELLED


class QAsyncioTimerHandle(QAsyncioHandle, asyncio.TimerHandle):
    def __init__(self, when: float, callback: Callable, args: tuple,
                 loop: QAsyncioEventLoop, context: contextvars.Context | None,
                 is_threadsafe: bool | None = False) -> None:
        QAsyncioHandle.__init__(self, callback, args, loop, context, is_threadsafe)

        self._when = when
        time = self._loop.time()

        # PYSIDE-2644: Timeouts should be rounded up or down instead of only up
        # as happens with int(). Otherwise, a timeout of e.g. 0.9 would be
        # handled as 0, where 1 would be more appropriate.
        self._timeout = round(max(self._when - time, 0) * 1000)

        QAsyncioHandle._start(self)

    def _start(self) -> None:
        """
        Overridden so that timer.start() is only called once at the end of the
        constructor for both QtHandle and QtTimerHandle.
        """
        pass

    def when(self) -> float:
        return self._when



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSensors, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSensors`

import PySide6.QtSensors
import PySide6.QtCore

import os
import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QAccelerometer(PySide6.QtSensors.QSensor):

    accelerationModeChanged  : typing.ClassVar[Signal] = ... # accelerationModeChanged(AccelerationMode)

    class AccelerationMode(enum.Enum):

        Combined                  = 0x0
        Gravity                   = 0x1
        User                      = 0x2


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, accelerationMode: PySide6.QtSensors.QAccelerometer.AccelerationMode | None = ...) -> None: ...

    def accelerationMode(self, /) -> PySide6.QtSensors.QAccelerometer.AccelerationMode: ...
    def reading(self, /) -> PySide6.QtSensors.QAccelerometerReading: ...
    def setAccelerationMode(self, accelerationMode: PySide6.QtSensors.QAccelerometer.AccelerationMode, /) -> None: ...


class QAccelerometerFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QAccelerometerReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QAccelerometerReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, x: float | None = ..., y: float | None = ..., z: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setX(self, x: float, /) -> None: ...
    def setY(self, y: float, /) -> None: ...
    def setZ(self, z: float, /) -> None: ...
    def x(self, /) -> float: ...
    def y(self, /) -> float: ...
    def z(self, /) -> float: ...


class QAmbientLightFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QAmbientLightReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QAmbientLightReading(PySide6.QtSensors.QSensorReading):

    class LightLevel(enum.Enum):

        Undefined                 = 0x0
        Dark                      = 0x1
        Twilight                  = 0x2
        Light                     = 0x3
        Bright                    = 0x4
        Sunny                     = 0x5


    def __init__(self, parent: PySide6.QtCore.QObject, /, *, lightLevel: PySide6.QtSensors.QAmbientLightReading.LightLevel | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def lightLevel(self, /) -> PySide6.QtSensors.QAmbientLightReading.LightLevel: ...
    def setLightLevel(self, lightLevel: PySide6.QtSensors.QAmbientLightReading.LightLevel, /) -> None: ...


class QAmbientLightSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QAmbientLightReading: ...


class QAmbientTemperatureFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QAmbientTemperatureReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QAmbientTemperatureReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, temperature: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setTemperature(self, temperature: float, /) -> None: ...
    def temperature(self, /) -> float: ...


class QAmbientTemperatureSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QAmbientTemperatureReading: ...


class QCompass(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QCompassReading: ...


class QCompassFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QCompassReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QCompassReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, azimuth: float | None = ..., calibrationLevel: float | None = ...) -> None: ...

    def azimuth(self, /) -> float: ...
    def calibrationLevel(self, /) -> float: ...
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setAzimuth(self, azimuth: float, /) -> None: ...
    def setCalibrationLevel(self, calibrationLevel: float, /) -> None: ...


class QGyroscope(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QGyroscopeReading: ...


class QGyroscopeFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QGyroscopeReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QGyroscopeReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, x: float | None = ..., y: float | None = ..., z: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setX(self, x: float, /) -> None: ...
    def setY(self, y: float, /) -> None: ...
    def setZ(self, z: float, /) -> None: ...
    def x(self, /) -> float: ...
    def y(self, /) -> float: ...
    def z(self, /) -> float: ...


class QHumidityFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QHumidityReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QHumidityReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, relativeHumidity: float | None = ..., absoluteHumidity: float | None = ...) -> None: ...

    def absoluteHumidity(self, /) -> float: ...
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def relativeHumidity(self, /) -> float: ...
    def setAbsoluteHumidity(self, value: float, /) -> None: ...
    def setRelativeHumidity(self, percent: float, /) -> None: ...


class QHumiditySensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QHumidityReading: ...


class QIRProximityFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QIRProximityReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QIRProximityReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, reflectance: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def reflectance(self, /) -> float: ...
    def setReflectance(self, reflectance: float, /) -> None: ...


class QIRProximitySensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QIRProximityReading: ...


class QIntList: ...


class QLidFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QLidReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QLidReading(PySide6.QtSensors.QSensorReading):

    backLidChanged           : typing.ClassVar[Signal] = ... # backLidChanged(bool)
    frontLidChanged          : typing.ClassVar[Signal] = ... # frontLidChanged(bool)

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, backLidClosed: bool | None = ..., frontLidClosed: bool | None = ...) -> None: ...

    def backLidClosed(self, /) -> bool: ...
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def frontLidClosed(self, /) -> bool: ...
    def setBackLidClosed(self, closed: bool, /) -> None: ...
    def setFrontLidClosed(self, closed: bool, /) -> None: ...


class QLidSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QLidReading: ...


class QLightFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QLightReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QLightReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, lux: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def lux(self, /) -> float: ...
    def setLux(self, lux: float, /) -> None: ...


class QLightSensor(PySide6.QtSensors.QSensor):

    fieldOfViewChanged       : typing.ClassVar[Signal] = ... # fieldOfViewChanged(double)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, fieldOfView: float | None = ...) -> None: ...

    def fieldOfView(self, /) -> float: ...
    def reading(self, /) -> PySide6.QtSensors.QLightReading: ...
    def setFieldOfView(self, fieldOfView: float, /) -> None: ...


class QMagnetometer(PySide6.QtSensors.QSensor):

    returnGeoValuesChanged   : typing.ClassVar[Signal] = ... # returnGeoValuesChanged(bool)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, returnGeoValues: bool | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QMagnetometerReading: ...
    def returnGeoValues(self, /) -> bool: ...
    def setReturnGeoValues(self, returnGeoValues: bool, /) -> None: ...


class QMagnetometerFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QMagnetometerReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QMagnetometerReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, x: float | None = ..., y: float | None = ..., z: float | None = ..., calibrationLevel: float | None = ...) -> None: ...

    def calibrationLevel(self, /) -> float: ...
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setCalibrationLevel(self, calibrationLevel: float, /) -> None: ...
    def setX(self, x: float, /) -> None: ...
    def setY(self, y: float, /) -> None: ...
    def setZ(self, z: float, /) -> None: ...
    def x(self, /) -> float: ...
    def y(self, /) -> float: ...
    def z(self, /) -> float: ...


class QOrientationFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QOrientationReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QOrientationReading(PySide6.QtSensors.QSensorReading):

    class Orientation(enum.Enum):

        Undefined                 = 0x0
        TopUp                     = 0x1
        TopDown                   = 0x2
        LeftUp                    = 0x3
        RightUp                   = 0x4
        FaceUp                    = 0x5
        FaceDown                  = 0x6


    def __init__(self, parent: PySide6.QtCore.QObject, /, *, orientation: PySide6.QtSensors.QOrientationReading.Orientation | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def orientation(self, /) -> PySide6.QtSensors.QOrientationReading.Orientation: ...
    def setOrientation(self, orientation: PySide6.QtSensors.QOrientationReading.Orientation, /) -> None: ...


class QOrientationSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QOrientationReading: ...


class QPressureFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QPressureReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QPressureReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, pressure: float | None = ..., temperature: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def pressure(self, /) -> float: ...
    def setPressure(self, pressure: float, /) -> None: ...
    def setTemperature(self, temperature: float, /) -> None: ...
    def temperature(self, /) -> float: ...


class QPressureSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QPressureReading: ...


class QProximityFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QProximityReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QProximityReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, close: bool | None = ...) -> None: ...

    def close(self, /) -> bool: ...
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setClose(self, close: bool, /) -> None: ...


class QProximitySensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QProximityReading: ...


class QRotationFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QRotationReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QRotationReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, x: float | None = ..., y: float | None = ..., z: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setFromEuler(self, x: float, y: float, z: float, /) -> None: ...
    def x(self, /) -> float: ...
    def y(self, /) -> float: ...
    def z(self, /) -> float: ...


class QRotationSensor(PySide6.QtSensors.QSensor):

    hasZChanged              : typing.ClassVar[Signal] = ... # hasZChanged(bool)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, hasZ: bool | None = ...) -> None: ...

    def hasZ(self, /) -> bool: ...
    def reading(self, /) -> PySide6.QtSensors.QRotationReading: ...
    def setHasZ(self, hasZ: bool, /) -> None: ...


class QSensor(PySide6.QtCore.QObject):

    activeChanged            : typing.ClassVar[Signal] = ... # activeChanged()
    alwaysOnChanged          : typing.ClassVar[Signal] = ... # alwaysOnChanged()
    availableSensorsChanged  : typing.ClassVar[Signal] = ... # availableSensorsChanged()
    axesOrientationModeChanged: typing.ClassVar[Signal] = ... # axesOrientationModeChanged(AxesOrientationMode)
    bufferSizeChanged        : typing.ClassVar[Signal] = ... # bufferSizeChanged(int)
    busyChanged              : typing.ClassVar[Signal] = ... # busyChanged()
    currentOrientationChanged: typing.ClassVar[Signal] = ... # currentOrientationChanged(int)
    dataRateChanged          : typing.ClassVar[Signal] = ... # dataRateChanged()
    efficientBufferSizeChanged: typing.ClassVar[Signal] = ... # efficientBufferSizeChanged(int)
    identifierChanged        : typing.ClassVar[Signal] = ... # identifierChanged()
    maxBufferSizeChanged     : typing.ClassVar[Signal] = ... # maxBufferSizeChanged(int)
    readingChanged           : typing.ClassVar[Signal] = ... # readingChanged()
    sensorError              : typing.ClassVar[Signal] = ... # sensorError(int)
    skipDuplicatesChanged    : typing.ClassVar[Signal] = ... # skipDuplicatesChanged(bool)
    userOrientationChanged   : typing.ClassVar[Signal] = ... # userOrientationChanged(int)

    class AxesOrientationMode(enum.Enum):

        FixedOrientation          = 0x0
        AutomaticOrientation      = 0x1
        UserOrientation           = 0x2

    class Feature(enum.Enum):

        Buffering                 = 0x0
        AlwaysOn                  = 0x1
        GeoValues                 = 0x2
        FieldOfView               = 0x3
        AccelerationMode          = 0x4
        SkipDuplicates            = 0x5
        AxesOrientation           = 0x6
        PressureSensorTemperature = 0x7
        Reserved                  = 0x101


    def __init__(self, type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, parent: PySide6.QtCore.QObject | None = ..., *, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview | None = ..., connectedToBackend: bool | None = ..., availableDataRates: collections.abc.Sequence[typing.Tuple[int, int]] | None = ..., dataRate: int | None = ..., reading: PySide6.QtSensors.QSensorReading | None = ..., busy: bool | None = ..., active: bool | None = ..., outputRanges: collections.abc.Sequence[PySide6.QtSensors.qoutputrange] | None = ..., outputRange: int | None = ..., description: str | None = ..., error: int | None = ..., alwaysOn: bool | None = ..., skipDuplicates: bool | None = ..., axesOrientationMode: PySide6.QtSensors.QSensor.AxesOrientationMode | None = ..., currentOrientation: int | None = ..., userOrientation: int | None = ..., maxBufferSize: int | None = ..., efficientBufferSize: int | None = ..., bufferSize: int | None = ...) -> None: ...

    def addFilter(self, filter: PySide6.QtSensors.QSensorFilter, /) -> None: ...
    def availableDataRates(self, /) -> typing.List[typing.Tuple[int, int]]: ...
    def axesOrientationMode(self, /) -> PySide6.QtSensors.QSensor.AxesOrientationMode: ...
    def backend(self, /) -> PySide6.QtSensors.QSensorBackend: ...
    def bufferSize(self, /) -> int: ...
    def connectToBackend(self, /) -> bool: ...
    def currentOrientation(self, /) -> int: ...
    def dataRate(self, /) -> int: ...
    @staticmethod
    def defaultSensorForType(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtCore.QByteArray: ...
    def description(self, /) -> str: ...
    def efficientBufferSize(self, /) -> int: ...
    def error(self, /) -> int: ...
    def filters(self, /) -> typing.List[PySide6.QtSensors.QSensorFilter]: ...
    def identifier(self, /) -> PySide6.QtCore.QByteArray: ...
    def isActive(self, /) -> bool: ...
    def isAlwaysOn(self, /) -> bool: ...
    def isBusy(self, /) -> bool: ...
    def isConnectedToBackend(self, /) -> bool: ...
    def isFeatureSupported(self, feature: PySide6.QtSensors.QSensor.Feature, /) -> bool: ...
    def maxBufferSize(self, /) -> int: ...
    def outputRange(self, /) -> int: ...
    def outputRanges(self, /) -> typing.List[PySide6.QtSensors.qoutputrange]: ...
    def reading(self, /) -> PySide6.QtSensors.QSensorReading: ...
    def removeFilter(self, filter: PySide6.QtSensors.QSensorFilter, /) -> None: ...
    @staticmethod
    def sensorTypes() -> typing.List[PySide6.QtCore.QByteArray]: ...
    @staticmethod
    def sensorsForType(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> typing.List[PySide6.QtCore.QByteArray]: ...
    def setActive(self, active: bool, /) -> None: ...
    def setAlwaysOn(self, alwaysOn: bool, /) -> None: ...
    def setAxesOrientationMode(self, axesOrientationMode: PySide6.QtSensors.QSensor.AxesOrientationMode, /) -> None: ...
    def setBufferSize(self, bufferSize: int, /) -> None: ...
    def setCurrentOrientation(self, currentOrientation: int, /) -> None: ...
    def setDataRate(self, rate: int, /) -> None: ...
    def setEfficientBufferSize(self, efficientBufferSize: int, /) -> None: ...
    def setIdentifier(self, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setMaxBufferSize(self, maxBufferSize: int, /) -> None: ...
    def setOutputRange(self, index: int, /) -> None: ...
    def setSkipDuplicates(self, skipDuplicates: bool, /) -> None: ...
    def setUserOrientation(self, userOrientation: int, /) -> None: ...
    def skipDuplicates(self, /) -> bool: ...
    def start(self, /) -> bool: ...
    def stop(self, /) -> None: ...
    def type(self, /) -> PySide6.QtCore.QByteArray: ...
    def userOrientation(self, /) -> int: ...


class QSensorBackend(PySide6.QtCore.QObject):

    def __init__(self, sensor: PySide6.QtSensors.QSensor, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def addDataRate(self, min: float, max: float, /) -> None: ...
    def addOutputRange(self, min: float, max: float, accuracy: float, /) -> None: ...
    def isFeatureSupported(self, feature: PySide6.QtSensors.QSensor.Feature, /) -> bool: ...
    def newReadingAvailable(self, /) -> None: ...
    def reading(self, /) -> PySide6.QtSensors.QSensorReading: ...
    def sensor(self, /) -> PySide6.QtSensors.QSensor: ...
    def sensorBusy(self, /, busy: bool = ...) -> None: ...
    def sensorError(self, error: int, /) -> None: ...
    def sensorStopped(self, /) -> None: ...
    def setDataRates(self, otherSensor: PySide6.QtSensors.QSensor, /) -> None: ...
    def setDescription(self, description: str, /) -> None: ...
    def start(self, /) -> None: ...
    def stop(self, /) -> None: ...


class QSensorBackendFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def createBackend(self, sensor: PySide6.QtSensors.QSensor, /) -> PySide6.QtSensors.QSensorBackend: ...


class QSensorChangesInterface(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def sensorsChanged(self, /) -> None: ...


class QSensorFilter(Shiboken.Object):

    m_sensor                  = ...  # type: PySide6.QtSensors.QSensor

    def __init__(self, /) -> None: ...

    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...
    def setSensor(self, sensor: PySide6.QtSensors.QSensor, /) -> None: ...


class QSensorManager(Shiboken.Object):

    def __init__(self, /) -> None: ...

    @staticmethod
    def createBackend(sensor: PySide6.QtSensors.QSensor, /) -> PySide6.QtSensors.QSensorBackend: ...
    @staticmethod
    def isBackendRegistered(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> bool: ...
    @staticmethod
    def registerBackend(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, factory: PySide6.QtSensors.QSensorBackendFactory, /) -> None: ...
    @staticmethod
    def setDefaultBackend(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @staticmethod
    def unregisterBackend(type: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, identifier: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...


class QSensorPluginInterface(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def registerSensors(self, /) -> None: ...


class QSensorReading(PySide6.QtCore.QObject):
    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setTimestamp(self, timestamp: int, /) -> None: ...
    def timestamp(self, /) -> int: ...
    def value(self, index: int, /) -> typing.Any: ...
    def valueCount(self, /) -> int: ...


class QTapFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QTapReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QTapReading(PySide6.QtSensors.QSensorReading):

    class TapDirection(enum.Enum):

        Undefined                 = 0x0
        X                         = 0x1
        Y                         = 0x2
        Z                         = 0x4
        X_Pos                     = 0x11
        Y_Pos                     = 0x22
        Z_Pos                     = 0x44
        X_Neg                     = 0x101
        X_Both                    = 0x111
        Y_Neg                     = 0x202
        Y_Both                    = 0x222
        Z_Neg                     = 0x404
        Z_Both                    = 0x444


    def __init__(self, parent: PySide6.QtCore.QObject, /, *, tapDirection: PySide6.QtSensors.QTapReading.TapDirection | None = ..., doubleTap: bool | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def isDoubleTap(self, /) -> bool: ...
    def setDoubleTap(self, doubleTap: bool, /) -> None: ...
    def setTapDirection(self, tapDirection: PySide6.QtSensors.QTapReading.TapDirection, /) -> None: ...
    def tapDirection(self, /) -> PySide6.QtSensors.QTapReading.TapDirection: ...


class QTapSensor(PySide6.QtSensors.QSensor):

    returnDoubleTapEventsChanged: typing.ClassVar[Signal] = ... # returnDoubleTapEventsChanged(bool)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, returnDoubleTapEvents: bool | None = ...) -> None: ...

    def reading(self, /) -> PySide6.QtSensors.QTapReading: ...
    def returnDoubleTapEvents(self, /) -> bool: ...
    def setReturnDoubleTapEvents(self, returnDoubleTapEvents: bool, /) -> None: ...


class QTiltFilter(PySide6.QtSensors.QSensorFilter):
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QTiltReading, /) -> bool: ...
    @typing.overload
    def filter(self, reading: PySide6.QtSensors.QSensorReading, /) -> bool: ...


class QTiltReading(PySide6.QtSensors.QSensorReading):

    def __init__(self, parent: PySide6.QtCore.QObject, /, *, yRotation: float | None = ..., xRotation: float | None = ...) -> None: ...

    def copyValuesFrom(self, other: PySide6.QtSensors.QSensorReading, /) -> None: ...
    def setXRotation(self, x: float, /) -> None: ...
    def setYRotation(self, y: float, /) -> None: ...
    def xRotation(self, /) -> float: ...
    def yRotation(self, /) -> float: ...


class QTiltSensor(PySide6.QtSensors.QSensor):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def calibrate(self, /) -> None: ...
    def reading(self, /) -> PySide6.QtSensors.QTiltReading: ...


class qoutputrange(Shiboken.Object):

    accuracy                  = ...  # type: float
    maximum                   = ...  # type: float
    minimum                   = ...  # type: float

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, qoutputrange: PySide6.QtSensors.qoutputrange, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
